@@ -1,6 +1,6 @@
 // ActivityMonitor.cc --- ActivityMonitor
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: ActivityMonitor.cc,v 1.7 2005/10/26 19:03:01 rcaelers Exp $";
+static const char rcsid[] = "$Id: ActivityMonitor.cc 1087 2006-10-01 18:40:08Z dotsphinx $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -45,7 +45,7 @@ static const char rcsid[] = "$Id: ActivityMonitor.cc,v 1.7 2005/10/26 19:03:01 r
 #if defined(HAVE_X)
 #include "X11InputMonitor.hh"
 #elif defined(WIN32)
-#include "Win32InputMonitor.hh"
+#include "W32InputMonitor.hh"
 #endif
 
 
@@ -92,7 +92,7 @@ ActivityMonitor::ActivityMonitor(const char *display) :
 #if defined(HAVE_X)
   input_monitor = new X11InputMonitor(display);
 #elif defined(WIN32)
-  input_monitor = new Win32InputMonitor();
+  input_monitor = new W32InputMonitor();
 #endif
 
   input_monitor->init(this);
@@ -264,6 +264,7 @@ ActivityMonitor::shift_time(int delta)
 {
   struct timeval d;
 
+  lock.lock();
   tvSETTIME(d, delta, 0)
     
   if (!tvTIMEEQ0(last_action_time))
@@ -274,6 +275,7 @@ ActivityMonitor::shift_time(int delta)
 
   if (!tvTIMEEQ0(last_mouse_time))
     tvADDTIME(last_mouse_time, last_mouse_time, d);
+  lock.unlock();
 }
 
 
@@ -368,7 +370,7 @@ ActivityMonitor::mouse_notify(int x, int y, int wheel_delta)
       gettimeofday(&now, NULL);
       tvSUBTIME(tv, now, last_mouse_time);
       
-      if (!tvTIMEEQ0(last_mouse_time) && tv.tv_sec < 1)
+      if (!tvTIMEEQ0(last_mouse_time) && tv.tv_sec < 1 && tv.tv_sec >= 0 && tv.tv_usec >= 0)
         {
           tvADDTIME(total_mouse_time, total_mouse_time, tv)
         }
