@@ -1,6 +1,6 @@
 // Break.cc
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,14 +14,13 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Break.cc,v 1.4 2005/04/23 19:53:01 rcaelers Exp $";
+static const char rcsid[] = "$Id: Break.cc 1090 2006-10-01 20:49:47Z dotsphinx $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "debug.hh"
-#include "nls.h"
 
 #include "Configurator.hh"
 #include "Core.hh"
@@ -106,7 +105,7 @@ Break::Break() :
 
 //! Initializes the break.
 void
-Break::init(BreakId id, AppInterface *app)
+Break::init(BreakId id, IApp *app)
 {
   TRACE_ENTER("Break::init");
 
@@ -293,12 +292,8 @@ int
 Break::get_timer_limit() const
 {
   int rc;
-  bool b = configurator->get_value(timer_prefix + CFG_KEY_TIMER_LIMIT, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].limit;
-    }
-  
+  configurator->get_value_default(timer_prefix + CFG_KEY_TIMER_LIMIT, &rc,
+                                  default_config[break_id].limit);
   return rc;
 }
 
@@ -316,12 +311,8 @@ int
 Break::get_timer_auto_reset() const
 {
   int rc;
-  bool b = configurator->get_value(timer_prefix + CFG_KEY_TIMER_AUTO_RESET, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].auto_reset;
-    }
-  
+  configurator->get_value_default(timer_prefix + CFG_KEY_TIMER_AUTO_RESET, &rc,
+                                  default_config[break_id].auto_reset);
   return rc;
 }
 
@@ -339,12 +330,8 @@ string
 Break::get_timer_reset_pred() const
 {
   string rc;
-  bool b = configurator->get_value(timer_prefix + CFG_KEY_TIMER_RESET_PRED, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].resetpred;
-    }
-  
+  configurator->get_value_default(timer_prefix + CFG_KEY_TIMER_RESET_PRED, &rc,
+                                  default_config[break_id].resetpred);
   return rc;
 }
 
@@ -362,12 +349,8 @@ int
 Break::get_timer_snooze() const
 {
   int rc;
-  bool b = configurator->get_value(timer_prefix + CFG_KEY_TIMER_SNOOZE, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].snooze;
-    }
-  
+  configurator->get_value_default(timer_prefix + CFG_KEY_TIMER_SNOOZE, &rc,
+                                  default_config[break_id].snooze);
   return rc;
 }
 
@@ -403,14 +386,10 @@ Break::set_timer_monitor(string n)
 bool
 Break::get_timer_activity_sensitive() const
 {
-  bool b;
   bool rc = true;
-  b = configurator->get_value(timer_prefix + CFG_KEY_TIMER_ACTIVITY_SENSITIVE, &rc);
-  if (! b)
-    {
-      rc = true;
-    }
-
+  configurator->get_value_default(timer_prefix
+                                  +CFG_KEY_TIMER_ACTIVITY_SENSITIVE,
+                                  &rc, true);
   return rc;
 }
 
@@ -426,12 +405,9 @@ int
 Break::get_break_max_preludes() const
 {
   int rc;
-  bool b = configurator->get_value(break_prefix + CFG_KEY_BREAK_MAX_PRELUDES, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].max_preludes;
-    }
-  
+  configurator->get_value_default(break_prefix + CFG_KEY_BREAK_MAX_PRELUDES,
+                                  &rc,
+                                  default_config[break_id].max_preludes);
   return rc;
 }
 
@@ -448,12 +424,9 @@ int
 Break::get_break_max_postpone() const
 {
   int rc;
-  bool b = configurator->get_value(break_prefix + CFG_KEY_BREAK_MAX_POSTPONE, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].max_postpone;
-    }
-  
+  configurator->get_value_default(break_prefix + CFG_KEY_BREAK_MAX_POSTPONE,
+                                  &rc,
+                                  default_config[break_id].max_postpone);
   return rc;
 }
 
@@ -469,13 +442,10 @@ Break::set_break_max_postpone(int n)
 bool
 Break::get_break_ignorable() const
 {
-  bool b;
   bool rc;
-  b = configurator->get_value(break_prefix + CFG_KEY_BREAK_IGNORABLE, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].ignorable_break;
-    }
+  configurator->get_value_default(break_prefix + CFG_KEY_BREAK_IGNORABLE,
+                                  &rc,
+                                  default_config[break_id].ignorable_break);
   return rc;
 }
 
@@ -492,13 +462,9 @@ Break::set_break_ignorable(bool b)
 int
 Break::get_break_exercises() const
 {
-  bool b;
   int rc;
-  b = configurator->get_value(break_prefix + CFG_KEY_BREAK_EXERCISES, &rc);
-  if (! b)
-    {
-      rc = default_config[break_id].exercises;
-    }
+  configurator->get_value_default(break_prefix + CFG_KEY_BREAK_EXERCISES, &rc,
+                                  default_config[break_id].exercises);
   return rc;
 }
 
@@ -514,13 +480,9 @@ Break::set_break_exercises(int n)
 bool
 Break::get_break_enabled() const
 {
-  bool b;
   bool rc;
-  b = configurator->get_value(break_prefix + CFG_KEY_BREAK_ENABLED, &rc);
-  if (! b)
-    {
-      rc = true;
-    }
+  configurator->get_value_default(break_prefix + CFG_KEY_BREAK_ENABLED, &rc,
+                                  true);
   return rc;
 }
 
