@@ -1,6 +1,6 @@
 // BreakControl.cc
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,13 +14,12 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: BreakControl.cc,v 1.10 2006/01/26 21:30:23 rcaelers Exp $";
+static const char rcsid[] = "$Id: BreakControl.cc 1128 2007-02-10 23:10:52Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "nls.h"
 #include "debug.hh"
 
 #include <assert.h>
@@ -28,11 +27,11 @@ static const char rcsid[] = "$Id: BreakControl.cc,v 1.10 2006/01/26 21:30:23 rca
 
 #include "BreakControl.hh"
 
-#include "BreakInterface.hh"
+#include "IBreak.hh"
 #include "Core.hh"
 #include "Statistics.hh"
-#include "AppInterface.hh"
-#include "ActivityMonitorInterface.hh"
+#include "IApp.hh"
+#include "IActivityMonitor.hh"
 #include "ActivityMonitorListener.hh"
 #include "Timer.hh"
 #include "Statistics.hh"
@@ -41,6 +40,9 @@ static const char rcsid[] = "$Id: BreakControl.cc,v 1.10 2006/01/26 21:30:23 rca
 #include "DistributionManager.hh"
 #endif
 
+#ifdef HAVE_DBUS
+#include "DBus.hh"
+#endif
 
 //! Construct a new Break Controller.
 /*!
@@ -50,7 +52,7 @@ static const char rcsid[] = "$Id: BreakControl.cc,v 1.10 2006/01/26 21:30:23 rca
  *          windows.
  *  \param timer pointer to the interface of the timer that belongs to this break.
  */
-BreakControl::BreakControl(BreakId id, Core *c, AppInterface *app, Timer *timer) :
+BreakControl::BreakControl(BreakId id, Core *c, IApp *app, Timer *timer) :
   break_id(id),
   core(c),
   application(app),
@@ -99,8 +101,8 @@ BreakControl::heartbeat()
     {
       // Prefer the running state of the break timer as input for
       // our current activity.
-      TimerInterface::TimerState tstate = break_timer->get_state();
-      is_idle = (tstate == TimerInterface::STATE_STOPPED);
+      ITimer::TimerState tstate = break_timer->get_state();
+      is_idle = (tstate == ITimer::STATE_STOPPED);
     }
   else
     {
@@ -169,20 +171,20 @@ BreakControl::heartbeat()
         else if (prelude_time == 20)
           {
             // Still not idle after 20s. Red alert.
-            application->set_prelude_stage(AppInterface::STAGE_ALERT);
+            application->set_prelude_stage(IApp::STAGE_ALERT);
             application->refresh_break_window();
           }
         else if (prelude_time == 10)
           {
             // Still not idle after 10s. Yellow alert.
-            application->set_prelude_stage(AppInterface::STAGE_WARN);
+            application->set_prelude_stage(IApp::STAGE_WARN);
             application->refresh_break_window();
           }
 
         if (prelude_time == 4)
           {
             // Move prelude window to top of screen after 4s.
-            application->set_prelude_stage(AppInterface::STAGE_MOVE_OUT);
+            application->set_prelude_stage(IApp::STAGE_MOVE_OUT);
           }
       } 
       break;
@@ -205,22 +207,28 @@ void
 BreakControl::goto_stage(BreakStage stage)
 {
   TRACE_ENTER_MSG("BreakControl::goto_stage", break_id << " " << stage);
+
+  send_signal(stage);
+  
   switch (stage)
     {
     case STAGE_DELAYED:
       {
-        ActivityMonitorInterface *monitor = core->get_activity_monitor();
+        IActivityMonitor *monitor = core->get_activity_monitor();
         monitor->set_listener(this);
+
+        break_timer->set_insensitive_mode(ITimer::MODE_IDLE_ON_LIMIT_REACHED);
       }
       break;
       
     case STAGE_NONE:
       {
         // Teminate the break.
+        break_timer->set_insensitive_mode(ITimer::MODE_IDLE_ON_LIMIT_REACHED);
         application->hide_break_window();
         core->defrost();
 
-        if (break_stage == STAGE_TAKING)
+        if (break_stage == STAGE_TAKING && !fake_break)
           {
             // Update statistics and play sound if the break end
             // was "natural"
@@ -265,6 +273,8 @@ BreakControl::goto_stage(BreakStage stage)
 
     case STAGE_PRELUDE:
       {
+        break_timer->set_insensitive_mode(ITimer::MODE_FOLLOW_IDLE);
+                                    
         prelude_count++;
         postponable_count++;
         prelude_time = 0;
@@ -278,6 +288,8 @@ BreakControl::goto_stage(BreakStage stage)
         
     case STAGE_TAKING:
       {
+        break_timer->set_insensitive_mode(ITimer::MODE_IDLE_ON_LIMIT_REACHED);
+
         // Remove the prelude window, if necessary.
         application->hide_break_window();
 
@@ -350,7 +362,6 @@ BreakControl::update_break_window()
   if (fake_break)
     {
       idle = duration - fake_break_count;
-
       if (fake_break_count <= 0)
         {
           stop_break(false);
@@ -638,15 +649,15 @@ BreakControl::prelude_window_start()
 
   application->start_prelude_window(break_id);
 
-  application->set_prelude_stage(AppInterface::STAGE_INITIAL);
+  application->set_prelude_stage(IApp::STAGE_INITIAL);
 
   if (!reached_max_prelude)
     {
-      application->set_prelude_progress_text(AppInterface::PROGRESS_TEXT_DISAPPEARS_IN);
+      application->set_prelude_progress_text(IApp::PROGRESS_TEXT_DISAPPEARS_IN);
     }
   else 
     {
-      application->set_prelude_progress_text(AppInterface::PROGRESS_TEXT_BREAK_IN);
+      application->set_prelude_progress_text(IApp::PROGRESS_TEXT_BREAK_IN);
     }
   
   update_prelude_window();
@@ -779,3 +790,44 @@ BreakControl::post_event(CoreEvent event)
     }
   TRACE_EXIT();
 }
+
+
+//! Send DBus signal when break stage changes.
+void
+BreakControl::send_signal(BreakStage stage)
+{
+  (void) stage;
+  
+#ifdef HAVE_DBUS
+  char *progress = NULL;
+  
+  switch (stage)
+    {
+    case STAGE_NONE:
+      progress = "none";
+      break;
+      
+    case STAGE_SNOOZED:
+      progress = "none";
+      break;
+
+    case STAGE_DELAYED:
+      // Do not send this stage.
+      break;
+        
+    case STAGE_PRELUDE:
+      progress = "prelude";
+      break;
+      
+    case STAGE_TAKING:
+      progress = "break";
+      break;
+    }
+
+  if (progress != NULL)
+    {
+      workrave_service_send_break_stage_signal(break_id, progress);
+    }
+  
+#endif
+}
