@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 // 
 
-static const char rcsid[] = "$Id: Configurator.cc,v 1.2 2006/02/14 19:18:24 rcaelers Exp $";
+static const char rcsid[] = "$Id: Configurator.cc 1095 2006-10-01 22:06:27Z dotsphinx $";
 
 
 #ifdef HAVE_CONFIG_H
@@ -26,8 +26,14 @@ static const char rcsid[] = "$Id: Configurator.cc,v 1.2 2006/02/14 19:18:24 rcae
 
 #include "Configurator.hh"
 #include "ConfiguratorListener.hh"
-#include "IniConfigurator.hh"
 
+#ifdef HAVE_GLIB
+#include "GlibIniConfigurator.hh"
+#endif
+#ifdef HAVE_QT
+#include "QtIniConfigurator.hh"
+#include "QtNativeConfigurator.hh"
+#endif
 #ifdef HAVE_GDOME
 #include "XMLConfigurator.hh"
 #endif
@@ -35,18 +41,18 @@ static const char rcsid[] = "$Id: Configurator.cc,v 1.2 2006/02/14 19:18:24 rcae
 #include "GConfConfigurator.hh"
 #endif
 #ifdef HAVE_REGISTRY
-#include "Win32Configurator.hh"
+#include "W32Configurator.hh"
 #endif
 
 
 //! Creates a configurator of the specified type.
 Configurator *
-Configurator::create(string type)
+Configurator::create(Format fmt)
 {
   Configurator *c =  NULL;
 
 #ifdef HAVE_GDOME  
-  if (type == "xml")
+  if (fmt == FormatXml)
     {
       c = new XMLConfigurator();
     }
@@ -54,7 +60,7 @@ Configurator::create(string type)
 #endif
     
 #ifdef HAVE_GCONF
-  if (type == "gconf")
+  if (fmt == FormatNative)
     {
       c = new GConfConfigurator();
     }
@@ -62,15 +68,30 @@ Configurator::create(string type)
 #endif
     
 #ifdef HAVE_REGISTRY
-  if (type == "w32")
+  if (fmt == FormatNative)
     {
-      c = new Win32Configurator();
+      c = new W32Configurator();
     }
   else
 #endif    
-  if (type == "ini")
+
+#ifdef HAVE_QT
+  if (fmt == FormatNative)
     {
-      c = new IniConfigurator();
+      c = new QtNativeConfigurator();
+    }
+  else
+#endif    
+
+  if (fmt == FormatIni)
+    {
+#ifdef HAVE_GLIB
+      c = new GlibIniConfigurator();
+#elif defined(HAVE_QT)
+      c = new QtIniConfigurator();
+#else
+#error Not ported
+#endif      
     }
   else
     {
@@ -291,3 +312,62 @@ Configurator::add_trailing_slash(string &key) const
         }
     }
 }
+
+void
+Configurator::get_value_default(string key, int *out, const int def) const
+{
+  bool b = get_value(key, out);
+  if (! b)
+    {
+      *out = def;
+      b = true;
+    }
+}
+
+
+
+void
+Configurator::get_value_default(string key, bool *out, const bool def) const
+{
+  bool b = get_value(key, out);
+  if (! b)
+    {
+      *out = def;
+    }
+}
+
+void
+Configurator::get_value_default(string key, string *out,
+                                const string def) const
+{
+  bool b = get_value(key, out);
+  if (! b)
+    {
+      *out = def;
+    }
+}
+
+
+void
+Configurator::get_value_default(string key, long *out,
+                                const long def) const
+{
+  bool b = get_value(key, out);
+  if (! b)
+    {
+      *out = def;
+    }
+}
+
+
+void
+Configurator::get_value_default(string key, double *out,
+                                const double def) const
+{
+  bool b = get_value(key, out);
+  if (! b)
+    {
+      *out = def;
+    }
+}
+
