@@ -1,6 +1,6 @@
 // Core.cc --- The main controller
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,13 +14,12 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Core.cc,v 1.18 2006/05/12 20:59:43 rcaelers Exp $";
+static const char rcsid[] = "$Id: Core.cc 1143 2007-03-02 22:45:18Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "nls.h"
 #include "debug.hh"
 
 #include <assert.h>
@@ -31,7 +30,7 @@ static const char rcsid[] = "$Id: Core.cc,v 1.18 2006/05/12 20:59:43 rcaelers Ex
 #include "Core.hh"
 
 #include "Util.hh"
-#include "AppInterface.hh"
+#include "IApp.hh"
 #include "CoreEventListener.hh"
 #include "ActivityMonitor.hh"
 #include "TimerActivityMonitor.hh"
@@ -57,16 +56,21 @@ static const char rcsid[] = "$Id: Core.cc,v 1.18 2006/05/12 20:59:43 rcaelers Ex
 #include <gconf/gconf-client.h>
 #endif
 
+#ifdef HAVE_DBUS
+#include "DBus.hh"
+#endif
+
 Core *Core::instance = NULL;
 
 const char *WORKRAVESTATE="WorkRaveState";
-const int SAVESTATETIME = 15;
+const int SAVESTATETIME = 60;
 
 const string Core::CFG_KEY_MONITOR = "monitor";
 const string Core::CFG_KEY_MONITOR_NOISE = "monitor/noise";
 const string Core::CFG_KEY_MONITOR_ACTIVITY = "monitor/activity";
 const string Core::CFG_KEY_MONITOR_IDLE = "monitor/idle";
 const string Core::CFG_KEY_GENERAL_DATADIR = "general/datadir";
+const string Core::CFG_KEY_OPERATION_MODE = "gui/operation-mode";
 
 //! Constructs a new Core.
 Core::Core() :
@@ -81,8 +85,8 @@ Core::Core() :
   powersave(false),
   powersave_resume_time(0),
   powersave_operation_mode(OPERATION_MODE_NORMAL),
-  insist_policy(CoreInterface::INSIST_POLICY_HALT),
-  active_insist_policy(CoreInterface::INSIST_POLICY_INVALID),
+  insist_policy(ICore::INSIST_POLICY_HALT),
+  active_insist_policy(ICore::INSIST_POLICY_INVALID),
   resume_break(BREAK_ID_NONE),
   local_state(ACTIVITY_IDLE),
   monitor_state(ACTIVITY_UNKNOWN)
@@ -121,9 +125,9 @@ Core::~Core()
       monitor->terminate();
     }
 
+  delete statistics;
   delete monitor;
   delete configurator;
-  delete statistics;
   
 #ifdef HAVE_DISTRIBUTION
   if (idlelog_manager != NULL)
@@ -149,7 +153,7 @@ Core::~Core()
 
 //! Initializes the core.
 void
-Core::init(int argc, char **argv, AppInterface *app, char *display_name)
+Core::init(int argc, char **argv, IApp *app, char *display_name)
 {
   application = app;
   this->argc = argc;
@@ -157,7 +161,7 @@ Core::init(int argc, char **argv, AppInterface *app, char *display_name)
   
   init_configurator();
   init_monitor(display_name);
-
+  
 #ifdef HAVE_DISTRIBUTION
   init_distribution_manager();
 #endif
@@ -166,6 +170,12 @@ Core::init(int argc, char **argv, AppInterface *app, char *display_name)
   init_statistics();
 
   load_state();
+  load_misc();
+
+#ifdef HAVE_DBUS
+  // FIXME: move..
+  workrave_dbus_server_init(this);
+#endif
 }
 
 
@@ -177,22 +187,22 @@ Core::init_configurator()
 
   if (Util::file_exists(ini_file))
     {
-      configurator = Configurator::create("ini");
+      configurator = Configurator::create(Configurator::FormatIni);
       configurator->load(ini_file);
     }
   else
     {
 #if defined(HAVE_REGISTRY)
-      configurator = Configurator::create("w32");
+      configurator = Configurator::create(Configurator::FormatNative);
 
 #elif defined(HAVE_GCONF)
       gconf_init(argc, argv, NULL);
       g_type_init();
-      configurator = Configurator::create("gconf");
+      configurator = Configurator::create(Configurator::FormatNative);
 
 #elif defined(HAVE_GDOME)
       string configFile = Util::complete_directory("config.xml", Util::SEARCH_PATH_CONFIG);
-      configurator = Configurator::create("xml");
+      configurator = Configurator::create(Configurator::FormatXml);
 
 #  if defined(HAVE_X)
       if (configFile == "" || configFile == "config.xml")
@@ -204,6 +214,8 @@ Core::init_configurator()
         {
           configurator->load(configFile);
         }
+#elif defined(HAVE_QT)
+      configurator = Configurator::create(Configurator::FormatNative);
 #else
 #error No configuator configured        
 #endif
@@ -212,7 +224,7 @@ Core::init_configurator()
   string home;
   if (configurator->get_value(CFG_KEY_GENERAL_DATADIR, &home))
     {
-      Util::set_home_directory(home + "/");
+      Util::set_home_directory(home);
     }
 }
 
@@ -399,7 +411,7 @@ Core::get_configurator() const
 
 
 //! Returns the activity monitor.
-ActivityMonitorInterface *
+IActivityMonitor *
 Core::get_activity_monitor() const
 {
   return monitor;
@@ -466,6 +478,12 @@ Core::set_operation_mode(OperationMode mode)
         {
           stop_all_breaks();
         }
+      
+      get_configurator()->set_value(CFG_KEY_OPERATION_MODE, mode);
+      if (core_event_listener != NULL)
+        {
+          core_event_listener->core_event_operation_mode_changed(mode);
+        }
     }
 
   return previous_mode;
@@ -522,8 +540,8 @@ Core::set_powersave(bool down)
       powersave_operation_mode = set_operation_mode(OPERATION_MODE_SUSPENDED);
       powersave_resume_time = 0;
       powersave = true;
-      save_state();
 
+      save_state();
       statistics->update();
     }
   else
@@ -548,11 +566,11 @@ Core::set_powersave(bool down)
  *  taking a break.
  */
 void
-Core::set_insist_policy(CoreInterface::InsistPolicy p)
+Core::set_insist_policy(ICore::InsistPolicy p)
 {
   TRACE_ENTER_MSG("Core::set_insist_policy", p);
 
-  if (active_insist_policy != CoreInterface::INSIST_POLICY_INVALID &&
+  if (active_insist_policy != ICore::INSIST_POLICY_INVALID &&
       insist_policy != p)
     {
       TRACE_MSG("refreeze " << active_insist_policy);
@@ -569,7 +587,7 @@ Core::set_insist_policy(CoreInterface::InsistPolicy p)
 
 
 //! Gets the insist policy.
-CoreInterface::InsistPolicy
+ICore::InsistPolicy
 Core::get_insist_policy() const
 {
   return insist_policy;
@@ -585,7 +603,7 @@ Core::force_idle()
 
   for (int i = 0; i < BREAK_ID_SIZEOF; i++)
     {
-      ActivityMonitorInterface *am = breaks[i].get_timer()->get_activity_monitor();
+      IActivityMonitor *am = breaks[i].get_timer()->get_activity_monitor();
       if (am != NULL)
         {
           am->force_idle();
@@ -915,7 +933,7 @@ Core::process_timewarp()
 
               force_idle();
 
-#ifdef WIN32              
+#ifdef WIN32
               monitor->shift_time(gap);
               for (int i = 0; i < BREAK_ID_SIZEOF; i++)
                 {
@@ -924,6 +942,7 @@ Core::process_timewarp()
               
               monitor_state = ACTIVITY_IDLE;
 #else
+              /* Assume it is a powersave... */
               int save_current_time = current_time;
               
               current_time = last_process_time + 1;
@@ -933,7 +952,6 @@ Core::process_timewarp()
 
               current_time = save_current_time;
 #endif
-              
             }
           else
             {
@@ -964,8 +982,9 @@ Core::process_timewarp()
 void
 Core::timer_action(BreakId id, TimerInfo info)
 {
-  // No breaks when mode is quiet.
-  if (operation_mode == OPERATION_MODE_QUIET)
+  // No breaks when mode is quiet,
+  if (operation_mode == OPERATION_MODE_QUIET &&
+      info.event == TIMER_EVENT_LIMIT_REACHED)
     {
       return;
     }
@@ -1159,6 +1178,19 @@ Core::save_state() const
 }
 
 
+//! Loads miscellaneous
+void
+Core::load_misc()
+{
+  int mode;
+  if (! get_configurator()->get_value(CFG_KEY_OPERATION_MODE, &mode))
+    {
+      mode = OPERATION_MODE_NORMAL;
+    }
+  set_operation_mode(OperationMode(mode));
+}
+
+
 //! Loads the current state.
 void
 Core::load_state()
@@ -1229,23 +1261,23 @@ void
 Core::freeze()
 {
   TRACE_ENTER_MSG("BreakControl::freeze", insist_policy);
-  CoreInterface::InsistPolicy policy = insist_policy;
+  ICore::InsistPolicy policy = insist_policy;
   
   switch (policy)
     {
-    case CoreInterface::INSIST_POLICY_IGNORE:
+    case ICore::INSIST_POLICY_IGNORE:
       {
         // Ignore all activity during break by suspending the activity monitor.
         monitor->suspend();
       }
       break;
-    case CoreInterface::INSIST_POLICY_HALT:
+    case ICore::INSIST_POLICY_HALT:
       {
         // Halt timer when the user is active.
         set_freeze_all_breaks(true);
       }
       break;
-    case CoreInterface::INSIST_POLICY_RESET:
+    case ICore::INSIST_POLICY_RESET:
       // reset the timer when the user becomes active.
       // default.
       break;
@@ -1267,13 +1299,16 @@ Core::defrost()
   
   switch (active_insist_policy)
     {
-    case CoreInterface::INSIST_POLICY_IGNORE:
+    case ICore::INSIST_POLICY_IGNORE:
       {
-        // Resumes the activity monitor.
-        monitor->resume();
+        // Resumes the activity monitor, if not suspended.
+        if (operation_mode != OPERATION_MODE_SUSPENDED)
+          {
+            monitor->resume();
+          }
       }
       break;
-    case CoreInterface::INSIST_POLICY_HALT:
+    case ICore::INSIST_POLICY_HALT:
       {
         // Desfrost timers.
         set_freeze_all_breaks(false);
@@ -1284,7 +1319,7 @@ Core::defrost()
       break;
     }
 
-  active_insist_policy = CoreInterface::INSIST_POLICY_INVALID;
+  active_insist_policy = ICore::INSIST_POLICY_INVALID;
   TRACE_EXIT();
 }
 
@@ -1605,6 +1640,21 @@ void
 Core::signon_remote_client(string client_id)
 {
   idlelog_manager->signon_remote_client(client_id);
+
+  if (master_node)
+    {
+      PacketBuffer buffer;
+      buffer.create();
+
+      ActivityState state = monitor->get_current_state();
+
+      buffer.pack_ushort(1);
+      buffer.pack_ushort(state);
+      
+      dist_manager->broadcast_client_message(DCM_MONITOR, buffer);
+
+      buffer.clear();
+    }
 }
 
 
