@@ -1,6 +1,6 @@
 // DistributionSocketLink.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2005, 2006 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
 //
 //
 
-static const char rcsid[] = "$Id: DistributionSocketLink.cc,v 1.6 2006/01/15 15:26:17 rcaelers Exp $";
+static const char rcsid[] = "$Id: DistributionSocketLink.cc 1144 2007-03-04 18:23:55Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -251,9 +251,7 @@ DistributionSocketLink::reconnect_all()
     {
       if ((*i)->type == CLIENTTYPE_DIRECT)
         {
-          (*i)->reconnect_count = reconnect_attempts;
-          (*i)->reconnect_time = time(NULL) - 1;          
-
+          close_client(*i, true);
           ret = true;
         }
       i++;
@@ -335,6 +333,17 @@ DistributionSocketLink::set_enabled(bool enabled)
 
   if (enabled)
     {
+      if (myname != NULL)
+        {
+          g_free(myname);
+          myname = NULL;
+        }
+      if (myid != NULL)
+        {
+          g_free(myid);
+          myid= NULL;
+        }
+      
       // Who am I?
       myname = socket_driver->get_my_canonical_name();
       if (myname != NULL)
@@ -383,7 +392,7 @@ DistributionSocketLink::set_enabled(bool enabled)
 bool
 DistributionSocketLink::register_client_message(DistributionClientMessageID id,
                                                 DistributionClientMessageType type,
-                                                DistributionClientMessageInterface *callback)
+                                                IDistributionClientMessage *callback)
 {
   ClientMessageListener sl;
   sl.listener = callback;
@@ -584,12 +593,14 @@ DistributionSocketLink::set_client_id(Client *client, gchar *id, gchar *name, gi
         }
       else if (old_client != client)
         {
+          TRACE_MSG("It's not me " << old_client->type << " " << old_client->socket);
           // It's a remote client, but not the same one.
 
           bool reuse = ((old_client->type == CLIENTTYPE_DIRECT ||
                          old_client->type == CLIENTTYPE_SIGNEDOFF)
                         && old_client->socket == NULL);
-          
+
+          TRACE_MSG("reuse " << reuse);
           if (reuse)
             {
               // Client exist, but is not connected.
@@ -735,7 +746,7 @@ DistributionSocketLink::close_client(Client *client, bool reconnect /* = false*/
             {
               TRACE_MSG("must reconnected");
               client->reconnect_count = reconnect_attempts;
-              client->reconnect_time = time(NULL) + reconnect_interval;
+              client->reconnect_time = time(NULL) + 5;
             }
           else
             {
@@ -1070,6 +1081,7 @@ DistributionSocketLink::process_client_packet(Client *client)
 //           send_duplicate(client);
 //           remove_client(client);
         }
+      g_free(id);
     }
 
   if (flags & PACKETFLAG_DEST)
@@ -1089,6 +1101,7 @@ DistributionSocketLink::process_client_packet(Client *client)
 
           source = NULL;
         }
+        g_free(id);
     }
   
   TRACE_MSG("size = " << size << ", version = " << version << ", flags = " << flags);
@@ -1252,8 +1265,9 @@ DistributionSocketLink::handle_hello(PacketBuffer &packet, Client *client)
   
   g_free(name);
   g_free(user);
+  g_free(id); 
   g_free(pass);
-    
+   
   TRACE_EXIT();
 }
 
@@ -1309,6 +1323,7 @@ DistributionSocketLink::handle_signoff(PacketBuffer &packet, Client *client)
   if (id != NULL)
     {
       c = find_client_by_id(id);
+      g_free(id);
     }
 
   if (c != NULL)
@@ -1322,6 +1337,13 @@ DistributionSocketLink::handle_signoff(PacketBuffer &packet, Client *client)
           TRACE_MSG("Direct connection. setting signedoff");
           c->type = CLIENTTYPE_SIGNEDOFF;
           remove_peer_clients(c);
+
+          if (c->socket != NULL)
+            {
+              TRACE_MSG("Remove connection");
+              delete c->socket;
+              c->socket = NULL;
+            }
         }
       else
         {
@@ -1416,6 +1438,9 @@ DistributionSocketLink::handle_welcome(PacketBuffer &packet, Client *client)
       send_duplicate(client);
       remove_client(client);
     }
+
+  g_free(id);
+  g_free(name);
   
   TRACE_EXIT();
 }
@@ -1833,7 +1858,7 @@ DistributionSocketLink::send_client_message(DistributionClientMessageType type)
       DistributionClientMessageID id = i->first;
       ClientMessageListener &sl = i->second;
       
-      DistributionClientMessageInterface *itf = sl.listener;
+      IDistributionClientMessage *itf = sl.listener;
 
       int pos = 0;
       packet.pack_ushort(id);
@@ -1964,7 +1989,9 @@ DistributionSocketLink::socket_io(SocketConnection *con, void *data)
 
   Client *client = (Client *)data;
   g_assert(client != NULL);
-
+ 
+  TRACE_MSG("1");
+ 
   if (!is_client_valid(client) && client->type == CLIENTTYPE_DIRECT)
     {
       TRACE_RETURN("Invalid client");
@@ -1975,18 +2002,27 @@ DistributionSocketLink::socket_io(SocketConnection *con, void *data)
   int bytes_read = 0;
   int bytes_to_read = 4;
 
+  TRACE_MSG("2 " << client->packet.read_ptr);
+
   if (client->packet.bytes_available() >= 4)
     {
+      TRACE_MSG("3");
+
       bytes_to_read = client->packet.peek_ushort(0) - 4;
 
+      TRACE_MSG("4 " << bytes_to_read);
+
       if (bytes_to_read + 4 > client->packet.get_buffer_size())
         {
+          TRACE_MSG("5 " << bytes_to_read << " " << client->packet.get_buffer_size());
           // FIXME: the 1024 is lame...
           client->packet.resize(bytes_to_read + 4 + 1024);
         }
     }
 
+  TRACE_MSG("5");
   bool ok = con->read(client->packet.get_write_ptr(), bytes_to_read, bytes_read);
+  TRACE_MSG("6 " << ok);
       
   if (!ok)
     {
