@@ -1,6 +1,6 @@
 // Statistics.cc
 //
-// Copyright (C) 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Statistics.cc,v 1.3 2005/01/24 22:41:29 rcaelers Exp $";
+static const char rcsid[] = "$Id: Statistics.cc 1112 2006-12-24 16:09:41Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -74,14 +74,13 @@ Statistics::init(Core *control)
   init_distribution_manager();
 #endif
 
-  current_day = new DailyStatsImpl();
+  current_day = NULL;
   bool ok = load_current_day();
   if (!ok)
     {
-      current_day = NULL;
       start_new_day();
     }
-  
+
   update_enviromnent();
   load_history();
 }
@@ -93,7 +92,7 @@ Statistics::update()
 {
   TRACE_ENTER("Statistics::update");
 
-  ActivityMonitorInterface *monitor = core->get_activity_monitor();
+  IActivityMonitor *monitor = core->get_activity_monitor();
   ActivityState state = monitor->get_current_state();
   
   if (state == ACTIVITY_ACTIVE && !been_active)
@@ -136,7 +135,7 @@ Statistics::start_new_day()
           day_to_history(current_day);
           day_to_remote_history(current_day);
         }
-
+      
       current_day = new DailyStatsImpl();
       been_active = false;
       
@@ -154,20 +153,20 @@ Statistics::start_new_day()
 void
 Statistics::day_to_history(DailyStatsImpl *stats)
 {
-  history.push_back(stats);
-  
+  add_history(stats);
+
   stringstream ss;
   ss << Util::get_home_directory();
   ss << "historystats" << ends;
-
+      
   bool exists = Util::file_exists(ss.str());
   ofstream stats_file(ss.str().c_str(), ios::app);
-
+      
   if (!exists)
     {
       stats_file << WORKRAVESTATS << " " << STATSVERSION  << endl;
     }
-
+      
   save_day(stats, stats_file);
   stats_file.close();
 
@@ -261,6 +260,7 @@ Statistics::add_history(DailyStatsImpl *stats)
     }
   else
     {
+      bool found = false;
       HistoryRIter i = history.rbegin();
       while (i != history.rend())
         {
@@ -270,7 +270,9 @@ Statistics::add_history(DailyStatsImpl *stats)
               stats->start.tm_mon == ref->start.tm_mon &&
               stats->start.tm_mday == ref->start.tm_mday)
             {
+              delete *i;
               *i = stats;
+              found = true;
               break;
             }
 
@@ -288,10 +290,16 @@ Statistics::add_history(DailyStatsImpl *stats)
               {
                 history.insert(i.base(), stats);
               }
+            found = true;
             break;
           }
           i++;
         }
+      
+      if (!found)
+        {
+          history.insert(history.begin(), stats);
+        }
     }
 }
 
@@ -306,128 +314,12 @@ Statistics::load_current_day()
 
   ifstream stats_file(ss.str().c_str());
 
-  bool ok = stats_file;
-
-  if (ok)
-    {
-      string tag;
-      stats_file >> tag;
-      
-      ok = (tag == WORKRAVESTATS);
-    }
-
-  if (ok)
-    {
-      int version;
-      stats_file >> version;
-
-      ok = (version == STATSVERSION) || (version == 3);
-    }
-
-  if (ok)
-    { 
-      string cmd;
-      stats_file >> cmd;
-
-      ok = (cmd == "D");
-    }
-
-  if (ok)
-    {
-      load_day(current_day, stats_file);
-    }
+  load(stats_file, false);
 
   been_active = true;
   
   TRACE_EXIT();
-  return ok;
-}
-
-
-//! Loads the statistics of a single day from the specified stream.
-void
-Statistics::load_day(DailyStatsImpl *stats, ifstream &stats_file)
-{
-  bool ok = stats_file;
-
-  if (ok)
-    {
-      stats_file >> stats->start.tm_mday 
-                 >> stats->start.tm_mon
-                 >> stats->start.tm_year
-                 >> stats->start.tm_hour
-                 >> stats->start.tm_min
-                 >> stats->stop.tm_mday 
-                 >> stats->stop.tm_mon
-                 >> stats->stop.tm_year
-                 >> stats->stop.tm_hour
-                 >> stats->stop.tm_min;
-        }
-  
-  while (ok && !stats_file.eof())
-    {
-      string cmd;
-      stats_file >> cmd;
-
-      if (cmd == "B")
-        {
-          int bt, size;
-          stats_file >> bt;
-          stats_file >> size;
-          
-          BreakStats &bs = stats->break_stats[bt];
-
-          if (size > STATS_BREAKVALUE_SIZEOF)
-            {
-              size = STATS_BREAKVALUE_SIZEOF;
-            }
-          
-          for(int j = 0; j < size; j++)
-            {
-              int value;
-              stats_file >> value;
-
-              bs[j] = value;
-            }
-        }
-      else if (cmd == "M" || cmd == "m")
-        {
-          int size;
-          stats_file >> size;
-          
-          if (size > STATS_VALUE_SIZEOF)
-            {
-             size = STATS_VALUE_SIZEOF;
-            }
-          
-          for(int j = 0; j < size; j++)
-            {
-              int value;
-              stats_file >> value;
-
-              if (cmd == "m")
-                {
-                  // Ignore older 'M' stats. they are broken....
-                  stats->misc_stats[j] = value;
-                }
-              else
-                {
-                  stats->misc_stats[j] = 0;
-                }
-            }
-        }
-      else if (cmd == "G")
-        {
-          int total_active;
-          stats_file >> total_active;
-
-          stats->misc_stats[STATS_VALUE_TOTAL_ACTIVE_TIME] = total_active;
-        }
-      else if (cmd == "D")
-        {
-          ok = false;
-        }
-    }
+  return current_day != NULL;
 }
 
 
@@ -443,12 +335,25 @@ Statistics::load_history()
 
   ifstream stats_file(ss.str().c_str());
 
-  bool ok = stats_file;
+  load(stats_file, true);
+  TRACE_EXIT();
+}
+
+
+//! Loads the statistics.
+void
+Statistics::load(ifstream &infile, bool history)
+{
+  TRACE_ENTER("Statistics::load");
+
+  DailyStatsImpl *stats = NULL;
+  
+  bool ok = infile;
 
   if (ok)
     {
       string tag;
-      stats_file >> tag;
+      infile >> tag;
 
       ok = (tag == WORKRAVESTATS);
     }
@@ -456,39 +361,120 @@ Statistics::load_history()
   if (ok)
     {
       int version;
-      stats_file >> version;
+      infile >> version;
 
       ok = (version == STATSVERSION) || (version == 3);
     }
 
 
-  bool first = true;
-  while (ok && !stats_file.eof())
+  while (ok && !infile.eof())
     {
-      string cmd;
+      char line[BUFSIZ] = "";
+      char cmd;
 
-      if (first)
+      infile.getline(line, BUFSIZ);
+
+      if (strlen(line) > 1)
         {
-          stats_file >> cmd;
-          
-          ok = cmd == "D";
-        }
+          cmd = line[0];
 
-      if (ok)
-        {
-          DailyStatsImpl *day = new DailyStatsImpl(); // FIXME: leak
-          
-          load_day(day, stats_file);
+          stringstream ss(line+1);
 
-          add_history(day);
-          first = false;
+          if (cmd == 'D')
+            {
+              if (history && stats != NULL)
+                {
+                  add_history(stats);
+                  stats = NULL;
+                }
+              else if (!history && stats != NULL)
+                {
+                  /* Corrupt today stats */
+                  return;
+                }
+
+              // FIXME: leak
+              stats = new DailyStatsImpl();
+          
+              ss >> stats->start.tm_mday 
+                 >> stats->start.tm_mon
+                 >> stats->start.tm_year
+                 >> stats->start.tm_hour
+                 >> stats->start.tm_min
+                 >> stats->stop.tm_mday 
+                 >> stats->stop.tm_mon
+                 >> stats->stop.tm_year
+                 >> stats->stop.tm_hour
+                 >> stats->stop.tm_min;
+
+              if (!history)
+                {
+                  current_day = stats;
+                }
+            }
+          else if (stats != NULL)
+            {
+              if (cmd == 'B')
+                {
+                  int bt, size;
+                  ss >> bt;
+                  ss >> size;
+          
+                  BreakStats &bs = stats->break_stats[bt];
+          
+                  if (size > STATS_BREAKVALUE_SIZEOF)
+                    {
+                      size = STATS_BREAKVALUE_SIZEOF;
+                    }
+          
+                  for(int j = 0; j < size; j++)
+                    {
+                      int value;
+                      ss >> value;
+              
+                      bs[j] = value;
+                    }
+                }
+              else if (cmd == 'M' || cmd == 'm')
+                {
+                  int size;
+                  ss >> size;
+          
+                  if (size > STATS_VALUE_SIZEOF)
+                    {
+                      size = STATS_VALUE_SIZEOF;
+                    }
+          
+                  for(int j = 0; j < size; j++)
+                    {
+                      int value;
+                      ss >> value;
+
+                      if (cmd == 'm')
+                        {
+                          // Ignore older 'M' stats. they are broken....
+                          stats->misc_stats[j] = value;
+                        }
+                      else
+                        {
+                          stats->misc_stats[j] = 0;
+                        }
+                    }
+                }
+              else if (cmd == 'G')
+                {
+                  int total_active;
+                  ss >> total_active;
+              
+                  stats->misc_stats[STATS_VALUE_TOTAL_ACTIVE_TIME] = total_active;
+                }
+            }
         }
     }
   TRACE_EXIT();
 }
 
 
-
 //! Increment the specified statistics counter of the current day.
 void
 Statistics::increment_break_counter(BreakId bt, StatsBreakValueType st)
@@ -687,7 +673,7 @@ Statistics::update_current_day(bool active)
 
       
       // Collect activity monitor stats.
-      ActivityMonitorInterface *monitor = core->get_activity_monitor();
+      IActivityMonitor *monitor = core->get_activity_monitor();
       assert(monitor != NULL);
 
       ActivityMonitorStatistics ams;
@@ -708,7 +694,7 @@ Statistics::update_enviromnent()
   if (core != NULL)
     {
       // Collect activity monitor stats.
-      ActivityMonitorInterface *monitor = core->get_activity_monitor();
+      IActivityMonitor *monitor = core->get_activity_monitor();
       assert(monitor != NULL);
 
       ActivityMonitorStatistics ams;
@@ -965,3 +951,4 @@ Statistics::DailyStatsImpl::starts_before_date(int y, int m, int d)
                   || (start.tm_mon + 1 == m
                       && start.tm_mday < d))));
 }
+
