@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Timer.cc,v 1.9 2006/05/12 20:59:43 rcaelers Exp $";
+static const char rcsid[] = "$Id: Timer.cc 1109 2006-11-13 19:16:52Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -65,7 +65,8 @@ Timer::Timer(TimeSource *time_source) :
   total_overdue_time(0),
   time_source(time_source),
   activity_monitor(NULL),
-  activity_sensitive(true)
+  activity_sensitive(true),
+  insensitive_mode(MODE_IDLE_ON_LIMIT_REACHED)
 {
 }
 
@@ -74,6 +75,7 @@ Timer::Timer(TimeSource *time_source) :
 Timer::~Timer()
 {
   delete autoreset_interval_predicate;
+  delete activity_monitor;
 }
 
 
@@ -207,6 +209,7 @@ Timer::set_auto_reset(long reset_time)
 void
 Timer::set_auto_reset(string predicate)
 {
+  delete autoreset_interval_predicate;
   autoreset_interval_predicate = TimePredFactory::create_time_pred(predicate);
   compute_next_predicate_reset_time();
 }
@@ -248,6 +251,13 @@ Timer::set_activity_sensitive(bool a)
     }
 }
 
+//! Sets the activity insensitive mode
+void
+Timer::set_insensitive_mode(InsensitiveMode mode)
+{
+  insensitive_mode = mode;
+}
+
 
 //! Forces a activity insensitive timer to become idle
 void
@@ -474,7 +484,9 @@ Timer::stop_timer()
           // But only if we are running...
           elapsed_time += (last_stop_time - last_start_time);
         }
-  
+
+      TRACE_MSG(elapsed_idle_time);
+      
       // Reset last start time.
       last_start_time = 0;
   
@@ -692,13 +704,18 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
           // Otherwise, use the previous state: A timer that is running keep
           // running until it is set to idle below. An idle timer (after limit
           // was reached) remains idle.
-          if (activity_state != ACTIVITY_ACTIVE && get_elapsed_time() == 0)
+          if (activity_state != ACTIVITY_ACTIVE) // RC: removed && get_elapsed_time() == 0)
             {
-              TRACE_MSG("new state1 = " << activity_state << " " << new_activity_state);
+              TRACE_MSG("new state1 = " << activity_state << " " << new_activity_state
+                        << last_limit_time);
             }
           else
             {
-              new_activity_state = activity_state;
+              if (insensitive_mode == MODE_IDLE_ON_LIMIT_REACHED)
+                {
+                  new_activity_state = activity_state;
+                }
+
               TRACE_MSG("new state2 = " << activity_state << " " << new_activity_state);
             }
 
