@@ -1,10 +1,8 @@
 // X11InputMonitor.cc --- ActivityMonitor for X11
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers <robc@krandor.org>
+// Copyright (C) 2001-2007 Rob Caelers <robc@krandor.org>
 // All rights reserved.
 //
-// Time-stamp: <2006-01-22 14:13:40 robc>
-//
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation; either version 2, or (at your option)
@@ -16,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: X11InputMonitor.cc,v 1.7 2006/01/22 13:13:48 rcaelers Exp $";
+static const char rcsid[] = "$Id: X11InputMonitor.cc 1134 2007-02-15 22:16:29Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -56,10 +54,15 @@ static const char rcsid[] = "$Id: X11InputMonitor.cc,v 1.7 2006/01/22 13:13:48 r
 #include <X11/Xmu/Error.h>
 
 #include "X11InputMonitor.hh"
-#include "InputMonitorListenerInterface.hh"
+#include "IInputMonitorListener.hh"
 
 #include "timeutil.h"
 
+#ifdef HAVE_APP_GTK
+#include <gdk/gdk.h>
+#endif
+
+#ifndef HAVE_APP_GTK  
 //! Intercepts X11 protocol errors.
 static int
 errorHandler(Display *dpy, XErrorEvent *error)
@@ -69,7 +72,7 @@ errorHandler(Display *dpy, XErrorEvent *error)
   XmuPrintDefaultErrorMessage(dpy,error,stderr);
   return 0;
 }
-
+#endif
 
 //! Obtains the next X11 event with specified timeout.
 static Bool
@@ -162,7 +165,7 @@ X11InputMonitor::~X11InputMonitor()
 
 
 void
-X11InputMonitor::init(InputMonitorListenerInterface *l)
+X11InputMonitor::init(IInputMonitorListener *l)
 {
   this->listener = l;
   monitor_thread->start();
@@ -226,14 +229,23 @@ X11InputMonitor::run_events()
 
   set_all_events(root_window);
 
+#ifdef HAVE_APP_GTK  
+  gdk_error_trap_push();
+#else
   int (*old_handler)(Display *dpy, XErrorEvent *error);
-
   old_handler = XSetErrorHandler(&errorHandler);
+#endif
+  
   XGrabButton(x11_display, AnyButton, AnyModifier, root_window, True,
               ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
   XSync(x11_display,False);
-  XSetErrorHandler(old_handler);
 
+#ifdef HAVE_APP_GTK  
+  gdk_error_trap_pop();
+#else
+  XSetErrorHandler(old_handler);
+#endif
+  
   Window lastMouseRoot = 0;
   while (1)
     {
@@ -325,13 +337,22 @@ X11InputMonitor::set_event_mask(Window window)
 void
 X11InputMonitor::set_all_events(Window window)
 {
-  int (*old_handler)(Display *dpy, XErrorEvent *error);
 
+#ifdef HAVE_APP_GTK  
+  gdk_error_trap_push();
+#else          
+  int (*old_handler)(Display *dpy, XErrorEvent *error);
   old_handler = XSetErrorHandler(&errorHandler);
+#endif
 
   set_event_mask(window);
   XSync(x11_display,False);
+
+#ifdef HAVE_APP_GTK  
+  gdk_error_trap_pop();
+#else
   XSetErrorHandler(old_handler);
+#endif
 }
 
 
@@ -339,34 +360,6 @@ void
 X11InputMonitor::handle_keypress(XEvent *event)
 {
   (void) event;
-  //printf("Key pressed ");
-
-#if 0
-  char *key;
-
-  key = XKeysymToString(XKeycodeToKeysym(x11_display, event->xkey.keycode, event->xkey.state));
-
-  if (key != 0)
-    {
-      printf("%s\n",key);
-    }
-  else
-    {
-      key = XKeysymToString(XKeycodeToKeysym(x11_display, event->xkey.keycode, 0));
-      
-      if (key != 0)
-        {
-          printf("'%s'\n",key);
-        }
-      else
-        {
-          printf("(%u,%u)\n", event->xkey.state, event->xkey.keycode);
-        }
-    }
-  
-  fflush(stdout);
-#endif
-  // FIXME:
   listener->keyboard_notify(0, 0);
 }
 
