@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Util.cc,v 1.3 2006/05/12 20:59:44 rcaelers Exp $";
+static const char rcsid[] = "$Id: Util.cc 1045 2006-09-20 17:26:32Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -44,6 +44,8 @@ extern "C" {
 HRESULT WINAPI SHGetSpecialFolderLocation(HWND,int,void**);
 BOOL WINAPI SHGetPathFromIDList(void *,LPSTR);
 VOID WINAPI CoTaskMemFree(PVOID);
+#define PathCanonicalize PathCanonicalizeA
+BOOL WINAPI PathCanonicalize(LPSTR,LPCSTR);
 #define CSIDL_APPDATA   26
 }
 // (end of hack)
@@ -122,7 +124,31 @@ Util::get_home_directory()
 void
 Util::set_home_directory(const string &home)
 {
-  home_directory = home;
+#ifdef WIN32
+  if (home.substr(0, 2) == ".\\" ||
+      home.substr(0, 3) == "..\\")
+    {
+      char buffer[MAX_PATH];
+      
+      // Path relative to location of workrave root.
+      string appdir = get_application_directory();
+
+      home_directory = appdir + "\\" + home + "\\";
+
+      PathCanonicalize(buffer, home_directory.c_str());
+      home_directory = buffer;
+    }
+  else
+#endif  
+    {
+      home_directory = home + "/";
+    }
+
+#ifdef WIN32
+  CreateDirectory(home_directory.c_str(), NULL);
+#else
+  mkdir(home_directory.c_str(), 0777);
+#endif      
 }
 
 //! Returns \c true if the specified file exists.
@@ -193,7 +219,7 @@ Util::get_search_path(SearchPathId type)
       searchPath.push_back("/usr/local/share/workrave/images");
       searchPath.push_back("/usr/share/workrave/images");
 #elif defined(WIN32)
-      searchPath.push_back(string(app_dir) + "\\share\\images");
+      searchPath.push_back(app_dir + "\\share\\images");
 #endif    
     }
   else if (type == SEARCH_PATH_CONFIG)
@@ -208,8 +234,8 @@ Util::get_search_path(SearchPathId type)
       searchPath.push_back("/usr/local/share/workrave/etc");
       searchPath.push_back("/usr/share/workrave/etc");
 #elif defined(WIN32)
-      searchPath.push_back(home_dir + "/");
-      searchPath.push_back(string(app_dir) + "\\etc");
+      searchPath.push_back(home_dir + "\\");
+      searchPath.push_back(app_dir + "\\etc");
 #endif    
     }
   else if (type == SEARCH_PATH_EXERCISES)
@@ -217,7 +243,7 @@ Util::get_search_path(SearchPathId type)
 #if defined(HAVE_X)
       searchPath.push_back(string(WORKRAVE_DATADIR) + "/exercises");
 #elif defined(WIN32)
-      searchPath.push_back(string(app_dir) + "\\share\\exercises");
+      searchPath.push_back(app_dir + "\\share\\exercises");
 #else
 #error Not properly ported.
 #endif    
