@@ -1,7 +1,7 @@
 /*
  * harpoon.c
  *
- * Copyright (C) 2002-2005 Raymond Penners <raymond@dotsphinx.com>
+ * Copyright (C) 2002-2007 Raymond Penners <raymond@dotsphinx.com>
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * $Id: harpoon.c,v 1.10 2005/04/23 20:16:12 rcaelers Exp $
+ * $Id: harpoon.c 1123 2007-02-04 20:24:06Z rcaelers $
  */
 
 #include <windows.h>
@@ -32,15 +32,24 @@
 #define HARPOON_MAX_UNBLOCKED_WINDOWS 16 /* Fixed, but ought to be enough... */
 #define HARPOON_WINDOW_CLASS "HarpoonNotificationWindow"
 
+#if defined(__GNUC__)
+#define DLLSHARE(v) v __attribute__((section (".shared"), shared))
+#else
+#define DLLSHARE(v) v
 #pragma comment(linker, "/SECTION:.shared,RWS")
 #pragma data_seg(".shared")
-HWND notification_window = NULL;
-HHOOK mouse_hook = NULL;
-HHOOK keyboard_hook = NULL;
-HHOOK keyboard_ll_hook = NULL;
-BOOL block_input = FALSE;
-HWND unblocked_windows[HARPOON_MAX_UNBLOCKED_WINDOWS];
+#endif
+HWND DLLSHARE(notification_window) = NULL;
+HHOOK DLLSHARE(mouse_hook) = NULL;
+HHOOK DLLSHARE(mouse_ll_hook) = NULL;
+HHOOK DLLSHARE(keyboard_hook) = NULL;
+HHOOK DLLSHARE(keyboard_ll_hook) = NULL;
+BOOL DLLSHARE(block_input) = FALSE;
+HWND DLLSHARE(unblocked_windows[HARPOON_MAX_UNBLOCKED_WINDOWS]);
+
+#if !defined(__GNUC__)
 #pragma data_seg()
+#endif
 
 static HANDLE dll_handle = NULL;
 static volatile HarpoonHookFunc user_callback = NULL;
@@ -333,7 +342,7 @@ harpoon_mouse_hook (int code, WPARAM wpar, LPARAM lpar)
         default:
           evt = HARPOON_MOUSE_MOVE;
         }
-      harpoon_post_message (evt, button, MAKELONG(x, y));
+/*       harpoon_post_message (evt, button, MAKELONG(x, y)); */
 
       if (evt == HARPOON_BUTTON_RELEASE)
         {
@@ -345,6 +354,87 @@ harpoon_mouse_hook (int code, WPARAM wpar, LPARAM lpar)
 }
 
 
+LRESULT CALLBACK
+harpoon_mouse_ll_hook (int code, WPARAM wpar, LPARAM lpar)
+{
+/*   BOOL forcecallnext = FALSE; */
+  if (code == HC_ACTION)
+    {
+      PMSLLHOOKSTRUCT pmhs = (PMSLLHOOKSTRUCT) lpar;
+      DWORD mouse_data = 0;
+      HarpoonEventType evt = HARPOON_NOTHING;
+      int button = -1;
+      int x = pmhs->pt.x;
+      int y = pmhs->pt.y;
+
+      if (harpoon_supports_mouse_hook_struct_ex())
+        {
+          mouse_data = pmhs->mouseData;
+        }
+
+
+      switch (wpar)
+        {
+        case WM_LBUTTONDOWN:
+          button = 0;
+          evt = HARPOON_BUTTON_PRESS;
+          break;
+        case WM_MBUTTONDOWN:
+          button = 1;
+          evt = HARPOON_BUTTON_PRESS;
+          break;
+        case WM_RBUTTONDOWN:
+          button = 2;
+          evt = HARPOON_BUTTON_PRESS;
+          break;
+  
+        case WM_LBUTTONUP:
+          button = 0;
+          evt = HARPOON_BUTTON_RELEASE;
+          break;
+        case WM_MBUTTONUP:
+          button = 1;
+          evt = HARPOON_BUTTON_RELEASE;
+          break;
+        case WM_RBUTTONUP:
+          button = 2;
+          evt = HARPOON_BUTTON_RELEASE;
+          break;
+
+        case WM_LBUTTONDBLCLK:
+          button = 0;
+          evt = HARPOON_2BUTTON_PRESS;
+          break;
+        case WM_MBUTTONDBLCLK:
+          button = 1;
+          evt = HARPOON_2BUTTON_PRESS;
+          break;
+        case WM_RBUTTONDBLCLK:
+          button = 2;
+          evt = HARPOON_2BUTTON_PRESS;
+          break;
+
+        case WM_MOUSEWHEEL:
+          evt = HARPOON_MOUSE_WHEEL;
+          button = mouse_data;
+          break;
+
+        default:
+          evt = HARPOON_MOUSE_MOVE;
+        }
+      harpoon_post_message (evt, button, MAKELONG(x, y));
+
+/*       if (evt == HARPOON_BUTTON_RELEASE) */
+/*         { */
+/*           forcecallnext = TRUE; */
+/*         } */
+    }
+/*   return harpoon_generic_hook_return (code, wpar, lpar, mouse_ll_hook, */
+/*                                       forcecallnext); */
+  return harpoon_generic_hook_return (code, wpar, lpar, mouse_ll_hook,
+                                      TRUE);
+}
+
 
 
 /**********************************************************************
@@ -506,6 +596,11 @@ harpoon_unhook ()
       UnhookWindowsHookEx(mouse_hook);
       mouse_hook = NULL;
     }
+  if (mouse_ll_hook)
+    {
+      UnhookWindowsHookEx(mouse_ll_hook);
+      mouse_ll_hook = NULL;
+    }
   if (keyboard_hook)
     {
       UnhookWindowsHookEx(keyboard_hook);
@@ -524,7 +619,12 @@ harpoon_hook (HarpoonHookFunc func)
 {
   harpoon_unhook();
   user_callback = func;
-  mouse_hook = SetWindowsHookEx(WH_MOUSE, harpoon_mouse_hook, dll_handle, 0);
+  mouse_ll_hook = SetWindowsHookEx(WH_MOUSE_LL, harpoon_mouse_ll_hook, dll_handle, 0);
+/*   if (mouse_ll_hook == NULL) */
+/*     { */
+      mouse_hook = SetWindowsHookEx(WH_MOUSE, harpoon_mouse_hook, dll_handle, 0);
+/*     } */
+  
   keyboard_ll_hook = SetWindowsHookEx(WH_KEYBOARD_LL, harpoon_keyboard_ll_hook, dll_handle, 0);
   if (keyboard_ll_hook == NULL)
     {
