@@ -1,6 +1,6 @@
 // BreakWindow.cc --- base class for the break windows
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: BreakWindow.cc,v 1.13 2005/07/04 19:52:27 rcaelers Exp $";
+static const char rcsid[] = "$Id: BreakWindow.cc 1090 2006-10-01 20:49:47Z dotsphinx $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -32,7 +32,7 @@ static const char rcsid[] = "$Id: BreakWindow.cc,v 1.13 2005/07/04 19:52:27 rcae
 #include <math.h>
 
 #include "BreakWindow.hh"
-#include "BreakResponseInterface.hh"
+#include "IBreakResponse.hh"
 #include "GtkUtil.hh"
 #include "WindowHints.hh"
 #include "Frame.hh"
@@ -83,7 +83,6 @@ BreakWindow::BreakWindow(BreakId break_id, HeadInfo &head,
       window->set_functions(Gdk::FUNC_MOVE);
     }
 
-  
   this->head = head;
 #ifdef HAVE_GTK_MULTIHEAD
   if (head.valid)
@@ -286,7 +285,7 @@ BreakWindow::on_delete_event(GdkEventAny *)
 
 //! Break response
 inline void
-BreakWindow::set_response(BreakResponseInterface *bri)
+BreakWindow::set_response(IBreakResponse *bri)
 {
   break_response = bri;
 }
@@ -376,6 +375,11 @@ BreakWindow::start()
 #endif  
   show_all();
 
+  // Set window hints.
+  WindowHints::set_skip_winlist(Gtk::Widget::gobj(), true);
+  WindowHints::set_always_on_top(Gtk::Widget::gobj(), true);
+  raise();
+  
 #ifdef CAUSES_FVWM_FOCUS_PROBLEMS
   present(); // After grab() please (Windows)
 #endif
@@ -409,7 +413,7 @@ BreakWindow::stop()
 //! Self-Destruct
 /*!
  *  This method MUST be used to destroy the objects through the
- *  BreakWindowInterface. it is NOT possible to do a delete on
+ *  IBreakWindow. it is NOT possible to do a delete on
  *  this interface...
  */
 void
