@@ -1,6 +1,6 @@
 // MainWindow.cc --- Main info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: MainWindow.cc,v 1.36 2006/01/26 18:37:10 rcaelers Exp $";
+static const char rcsid[] = "$Id: MainWindow.cc 1135 2007-02-19 18:57:27Z rcaelers $";
 
 #include "preinclude.h"
 
@@ -25,7 +25,6 @@ static const char rcsid[] = "$Id: MainWindow.cc,v 1.36 2006/01/26 18:37:10 rcael
 #ifdef WIN32
 #include <gdk/gdkwin32.h>
 #include <shellapi.h>
-#include <pbt.h>
 #endif
 
 #include "nls.h"
@@ -38,9 +37,7 @@ static const char rcsid[] = "$Id: MainWindow.cc,v 1.36 2006/01/26 18:37:10 rcael
 #include <gnome.h>
 #endif
 
-#if defined(HAVE_GNOME) || defined(HAVE_KDE)
-#include "AppletWindow.hh"
-#endif
+#include "AppletControl.hh"
 
 #include "TimerBoxGtkView.hh"
 #include "TimerBoxControl.hh"
@@ -51,12 +48,15 @@ static const char rcsid[] = "$Id: MainWindow.cc,v 1.36 2006/01/26 18:37:10 rcael
 #include "TimeBar.hh"
 #include "GUI.hh"
 #include "Util.hh"
+#ifdef WIN32
+#include "StatusIcon.hh"
+#endif
 #include "Text.hh"
 
 #include "CoreFactory.hh"
-#include "ConfiguratorInterface.hh"
-#include "TimerInterface.hh"
-#include "StatisticsInterface.hh"
+#include "IConfigurator.hh"
+#include "ITimer.hh"
+#include "IStatistics.hh"
 
 #ifdef HAVE_DISTRIBUTION
 #include "NetworkJoinDialog.hh"
@@ -121,7 +121,6 @@ MainWindow::~MainWindow()
   TRACE_ENTER("MainWindow::~MainWindow");
   delete timer_box_control;
 #ifdef WIN32
-  delete win32_timer_box_control;
   win32_exit();
 #endif
 #ifdef HAVE_X
@@ -164,18 +163,15 @@ MainWindow::init()
   Gtk::Window::set_default_icon_list(icon_list);
     
   enabled = TimerBoxControl::is_enabled("main_window");
-#ifdef WIN32
-  win32_timer_box_control
-    = new TimerBoxControl("applet", win32_timer_box_view);
-#endif
 
   Menus *menus = Menus::get_instance();
   menus->set_main_window(this);
-  popup_menu = menus->create_main_window_menu();
+  menus->create_menu(Menus::MENU_MAINWINDOW);
   
   timer_box_view = manage(new TimerBoxGtkView());
   timer_box_control = new TimerBoxControl("main_window", *timer_box_view);
-  timer_box_view->set_geometry(true, -1);
+  timer_box_view->set_geometry(ORIENTATION_LEFT, -1);
+  timer_box_control->update();
   add(*timer_box_view);
 
   set_events(get_events() | Gdk::BUTTON_PRESS_MASK | Gdk::SUBSTRUCTURE_MASK);
@@ -184,6 +180,15 @@ MainWindow::init()
   realize_if_needed();
 
   Glib::RefPtr<Gdk::Window> window = get_window();
+
+  // Window decorators
+  window->set_decorations(Gdk::DECOR_BORDER
+                          |Gdk::DECOR_TITLE
+                          |Gdk::DECOR_MENU);
+  // This used to be W32 only:
+  //   window->set_functions(Gdk::FUNC_CLOSE|Gdk::FUNC_MOVE);
+  
+  // (end window decorators)
   
 #ifdef HAVE_X
   // HACK. this sets a different group leader in the WM_HINTS....
@@ -198,16 +203,12 @@ MainWindow::init()
   setup();
   
 #ifdef WIN32
-  window->set_functions(Gdk::FUNC_CLOSE|Gdk::FUNC_MOVE);
 
   win32_init();
-  menus->set_applet_window(&win32_timer_box_view);
-  menus->resync_applet();
-
   set_gravity(Gdk::GRAVITY_STATIC); 
   set_position(Gtk::WIN_POS_NONE);
 
-#ifdef HAVE_PROPER_SIZED_MAIN_WINDOW_ON_STARTUP
+#ifndef HAVE_NOT_PROPER_SIZED_MAIN_WINDOW_ON_STARTUP 
   // This is the proper code, see hacked code below.
   if (!enabled)
     {
@@ -221,7 +222,8 @@ MainWindow::init()
       move_to_start_position();;
       show_all();
     }
-#else
+#else // Hack deprecated: Since GTK+ 2.10 no longer necessary
+  
   // Hack: since GTK+ 2.2.4 the window is too wide, it incorporates room
   // for the "_ [ ] [X]" buttons somehow. This hack fixes just that.
   move(-1024, 0); // Move off-screen to reduce wide->narrow flickering
@@ -253,9 +255,10 @@ MainWindow::init()
   setup();
   set_title("Workrave");
 
-  ConfiguratorInterface *config = CoreFactory::get_configurator();
+  IConfigurator *config = CoreFactory::get_configurator();
   config->add_listener(TimerBoxControl::CFG_KEY_TIMERBOX + "main_window", this);
 
+
   TRACE_EXIT();
 }
 
@@ -302,9 +305,12 @@ void
 MainWindow::update()
 {
   timer_box_control->update();
-#ifdef WIN32
-  win32_timer_box_control->update();
-#endif
+}
+
+
+void MainWindow::on_activate()
+{
+  open_window();
 }
 
 
@@ -383,11 +389,10 @@ MainWindow::on_delete_event(GdkEventAny *)
   
 #if defined(HAVE_GNOME) || defined(HAVE_KDE)
   bool terminate = true;
-  AppletWindow *applet = gui->get_applet_window();
-  if (applet != NULL)
+  AppletControl *applet_control = gui->get_applet_control();
+  if (applet_control != NULL)
     {
-      AppletWindow::AppletMode mode = applet->get_applet_mode();
-      terminate = mode == AppletWindow::APPLET_DISABLED;
+      terminate = !applet_control->is_visible();
     }
   
   if (terminate)
@@ -419,7 +424,8 @@ MainWindow::on_button_press_event(GdkEventButton *event)
 
   if ((event->type == GDK_BUTTON_PRESS) && (event->button == 3))
     {
-      popup_menu->popup(event->button, event->time);
+      Menus::get_instance()->popup(Menus::MENU_MAINWINDOW,
+                                   event->button, event->time);
       ret = true;
     }
 
@@ -428,6 +434,7 @@ MainWindow::on_button_press_event(GdkEventButton *event)
 }
 
 
+
 bool
 MainWindow::on_window_state_event(GdkEventWindowState *event)
 {
@@ -462,14 +469,11 @@ MainWindow::config_changed_notify(string key)
 bool
 MainWindow::get_always_on_top() 
 {
-  bool b;
   bool rc;
-  b = CoreFactory::get_configurator()
-    ->get_value(MainWindow::CFG_KEY_MAIN_WINDOW_ALWAYS_ON_TOP, &rc);
-  if (! b)
-    {
-      rc = false;
-    }
+  CoreFactory::get_configurator()
+    ->get_value_default(MainWindow::CFG_KEY_MAIN_WINDOW_ALWAYS_ON_TOP,
+                        &rc,
+                        false);
   return rc;
 }
 
@@ -485,14 +489,9 @@ MainWindow::set_always_on_top(bool b)
 bool
 MainWindow::get_start_in_tray() 
 {
-  bool b;
   bool rc;
-  b = CoreFactory::get_configurator()
-    ->get_value(CFG_KEY_MAIN_WINDOW_START_IN_TRAY, &rc);
-  if (! b)
-    {
-      rc = false;
-    }
+  CoreFactory::get_configurator()
+    ->get_value_default(CFG_KEY_MAIN_WINDOW_START_IN_TRAY, &rc, false);
   return rc;
 }
 
@@ -522,94 +521,6 @@ MainWindow::win32_show(bool b)
     }
 }
 
-static GdkFilterReturn
-win32_filter_func (void     *xevent,
-		    GdkEvent *event,
-		    gpointer  data)
-{
-  TRACE_ENTER("MainWindow::win32_filter_func");
-
-  (void) event;
-  (void) data;
-  
-  MSG *msg = (MSG *) xevent;
-  GdkFilterReturn ret = GDK_FILTER_CONTINUE;
-  switch (msg->message)
-    {
-    case WM_POWERBROADCAST:
-      {
-        TRACE_MSG("WM_POWERBROADCAST " << msg->wParam << " " << msg->lParam);
-          switch (msg->wParam)
-            {
-            case PBT_APMQUERYSUSPEND:
-              TRACE_MSG("Query Suspend");
-              break;
-
-            case PBT_APMQUERYSUSPENDFAILED:
-              TRACE_MSG("Query Suspend Failed");
-              break;
-
-            case PBT_APMRESUMESUSPEND:
-              {
-                TRACE_MSG("Resume suspend");
-                CoreInterface *core = CoreFactory::get_core();
-                if (core != NULL)
-                  {
-                    core->set_powersave(false);
-                  }
-              }
-              break;
-
-            case PBT_APMSUSPEND:
-              {
-                TRACE_MSG("Suspend");
-                CoreInterface *core = CoreFactory::get_core();
-                if (core != NULL)
-                  {
-                    core->set_powersave(true);
-                  }
-              }
-              break;
-            }
-      }
-      break;
-
-    case WM_DISPLAYCHANGE:
-      {
-        TRACE_MSG("WM_DISPLAYCHANGE " << msg->wParam << " " << msg->lParam);
-        GUI *gui = GUI::get_instance(); 
-        assert(gui != NULL);
-        gui->init_multihead();
-      }
-      break;
-
-    case WM_USER:
-      {
-        Menus *menus = Menus::get_instance();
-        menus->on_applet_command((short) msg->wParam);
-        ret = GDK_FILTER_REMOVE;
-      }
-      break;
-
-    case WM_USER + 1:
-      {
-        GUI *gui = GUI::get_instance(); 
-        assert(gui != NULL);
-
-        MainWindow *main_window = gui->get_main_window();
-        assert(main_window != NULL);
-        
-        TimerBoxControl *win32_timer_box_control = main_window->get_win32_timer_box_control();
-        win32_timer_box_control->force_cycle();
-        
-        ret = GDK_FILTER_REMOVE;
-      }
-      break;
-    }
-
-  TRACE_EXIT();
-  return ret;
-}
 
 void
 MainWindow::win32_init()
@@ -656,280 +567,32 @@ MainWindow::win32_init()
   HWND hwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
   SetWindowLong(hwnd, GWL_HWNDPARENT, (LONG) win32_main_hwnd);
 
-  // Filter
-  gdk_window_add_filter(gdk_window, win32_filter_func, this);
-  
-  // Tray icon
-  wm_taskbarcreated = RegisterWindowMessage("TaskbarCreated");
-  win32_add_tray_icon();
-
-  // Tray menu
-  Menus *menus = Menus::get_instance();
-  win32_tray_menu = menus->create_tray_menu();
-
-//   win32_tray_menu->signal_leave_notify_event().connect(MEMBER_SLOT(*this, &MainWindow::win32_on_leave_notify));
-//   win32_tray_menu->signal_enter_notify_event().connect(MEMBER_SLOT(*this, &MainWindow::win32_on_enter_notify));
-//   win32_tray_menu->add_events(Gdk::ENTER_NOTIFY_MASK | Gdk::LEAVE_NOTIFY_MASK);
-
-  Gtk::Menu::MenuList &menulist = win32_tray_menu->items();
-
-  menulist.push_front(Gtk::Menu_Helpers::StockMenuElem
-                      (Gtk::Stock::OPEN,
-                       MEMBER_SLOT(*this, &MainWindow::win32_on_tray_open)));
   TRACE_EXIT();
 }
 
 void
 MainWindow::win32_exit()
 {
-  // Destroy tray
-  Shell_NotifyIcon(NIM_DELETE, &win32_tray_icon);
   DestroyWindow(win32_main_hwnd);
   UnregisterClass(WIN32_MAIN_CLASS_NAME, GetModuleHandle(NULL));
 }
 
-void
-MainWindow::win32_add_tray_icon()
-{
-  normal_icon = LoadIcon(win32_hinstance, "workrave");
-  quiet_icon = LoadIcon(win32_hinstance, "workravequiet");
-  suspended_icon = LoadIcon(win32_hinstance, "workravesusp");
-
-  memset(&win32_tray_icon, 0, sizeof(NOTIFYICONDATA));
-    
-  win32_tray_icon.cbSize = sizeof(NOTIFYICONDATA);
-  win32_tray_icon.hWnd = win32_main_hwnd;
-  win32_tray_icon.uID = 1;
-  win32_tray_icon.uFlags = NIF_ICON|NIF_TIP|NIF_MESSAGE; //|0x00000010; // NIF_INFO;
-  win32_tray_icon.uCallbackMessage = MYWM_TRAY_MESSAGE;
-  win32_tray_icon.hIcon = normal_icon;
-  strcpy(win32_tray_icon.szTip, "Workrave");
-
-  // Balloon: not used.
-  //win32_tray_icon.dwInfoFlags = 0; // NIIF_NONE;
-  //win32_tray_icon.uTimeout = 0; // 5 * 1000;
-  //strcpy(win32_tray_icon.szInfoTitle, "Workrave");
-  //strncpy(win32_tray_icon.szInfo, "Workrave", 255);
-
-  Shell_NotifyIcon(NIM_ADD, &win32_tray_icon);
-  DestroyIcon(win32_tray_icon.hIcon);
-}
-
-void
-MainWindow::win32_set_tray_tooltip(string tip)
-{
-  char *text = NULL;
-  const char *tip_locale = tip.c_str();
-
-  GError *error = NULL;
-  
-  text = g_locale_from_utf8(tip_locale, -1, NULL, NULL, &error);
-
-  if (error != NULL)
-    {
-      TRACE_ENTER("MainWindow::win32_set_tray_tooltip");
-      TRACE_MSG(error->message);
-      TRACE_EXIT();
-      g_error_free(error);
-    } 
-
-  if (text != NULL)
-    {    
-      strncpy(win32_tray_icon.szTip, text, 127);
-    }
-  else
-    {
-      strncpy(win32_tray_icon.szTip, "Workrave", 127);
-    }
-      
-  Shell_NotifyIcon(NIM_MODIFY, &win32_tray_icon);
-}
-
-
-void
-MainWindow::win32_set_tray_icon(TimerBoxView::IconType icon)
-{
-  string file;  
-  switch (icon)
-    {
-    case TimerBoxView::ICON_NORMAL:
-      win32_tray_icon.hIcon = normal_icon;
-      break;
-      
-    case TimerBoxView::ICON_QUIET:
-      win32_tray_icon.hIcon = quiet_icon;
-      break;
-      
-    case TimerBoxView::ICON_SUSPENDED:
-      win32_tray_icon.hIcon = suspended_icon;
-    }
-  
-  Shell_NotifyIcon(NIM_MODIFY, &win32_tray_icon);
-}
-
-/* Taken from Gaim. needs to be gtkmm-ified. */
-/* This is a workaround for a bug in windows GTK+. Clicking outside of the
-   menu does not get rid of it, so instead we get rid of it as soon as the
-   pointer leaves the menu. */
-static gboolean 
-win32_hide_menu(gpointer data)
-{
-	if (data != NULL) {
-		gtk_menu_popdown(GTK_MENU(data));
-	}
-	return FALSE;
-}
-
-static gboolean
-win32_menu_leave_enter(GtkWidget *menu, GdkEventCrossing *event, void *data)
-{
-  TRACE_ENTER("win32_menu_leave_enter");
-  static guint hide_docklet_timer = 0;
-  if (event->type == GDK_LEAVE_NOTIFY && event->detail == GDK_NOTIFY_ANCESTOR) {
-    /* Add some slop so that the menu doesn't annoyingly disappear when mousing around */
-    if (hide_docklet_timer == 0) {
-      hide_docklet_timer = g_timeout_add(500, win32_hide_menu, menu);
-    }
-  } else if (event->type == GDK_ENTER_NOTIFY && event->detail == GDK_NOTIFY_ANCESTOR) {
-    if (hide_docklet_timer != 0) {
-      /* Cancel the hiding if we reenter */
-      
-      g_source_remove(hide_docklet_timer);
-      hide_docklet_timer = 0;
-    }
-  }
-  TRACE_EXIT();
-  return FALSE;
-}
-
-LRESULT CALLBACK
-MainWindow::win32_window_proc(HWND hwnd, UINT uMsg, WPARAM wParam,
-                              LPARAM lParam)
-{
-  TRACE_ENTER("MainWindow::win32_window_proc");
-  static bool connect_once = false;
-  MainWindow *win = (MainWindow *) GetWindowLong(hwnd, GWL_USERDATA);
-  if (win != NULL)
-    {
-      if (uMsg == win->wm_taskbarcreated)
-        {
-          win->win32_add_tray_icon();
-        }
-      else if (uMsg == MYWM_TRAY_MESSAGE)
-        {
-          MainWindow *win;
-          win = (MainWindow *) GetWindowLong(hwnd, GWL_USERDATA);
-          switch (lParam)
-            {
-            case WM_RBUTTONUP:
-              {
-                GtkWidget *window = (GtkWidget*) win->win32_tray_menu->gobj();
-                GdkWindow *gdk_window = window->window;
-                HWND phwnd = (HWND) GDK_WINDOW_HWND(gdk_window);
-                SetForegroundWindow(phwnd);
-
-                if (!connect_once)
-                  {
-                    // RC: FIXME: remove this c hack HACK 
-                    TRACE_MSG("connect");
-                    g_signal_connect(window, "leave-notify-event", G_CALLBACK(win32_menu_leave_enter), NULL);
-                    g_signal_connect(window, "enter-notify-event", G_CALLBACK(win32_menu_leave_enter), NULL);
-                    connect_once = true;
-                    TRACE_MSG("connect ok");
-                  }
-                
-                win->win32_tray_menu->popup(0,  GetTickCount());
-              }
-              break;
-            case WM_LBUTTONDBLCLK:
-              win->open_window();
-              break;
-            }
-        }
-    }
-  
-  TRACE_EXIT();
-  return DefWindowProc(hwnd, uMsg, wParam, lParam);
-}
-
-//! User requested immediate restbreak.
-void
-MainWindow::win32_on_tray_open()
-{
-  win32_show(true);
-}
-
-
-bool
-MainWindow::win32_on_leave_notify(GdkEventCrossing *event)
-{
-  TRACE_ENTER("MainWindow:win32_on_leave_notify")
-  if (event->detail == GDK_NOTIFY_ANCESTOR &&
-      !timeout_connection.connected())
-    {
-      timeout_connection = Glib::signal_timeout().connect(MEMBER_SLOT(*this,
-                                                                      &MainWindow::win32_on_hide_timer),
-                                                          500);
-    }
-
-  TRACE_EXIT();
-  return false;
-}
-
-
-bool
-MainWindow::win32_on_enter_notify(GdkEventCrossing *event)
-{
-  TRACE_ENTER("MainWindow:win32_on_enter_notify")
-  if (event->detail == GDK_NOTIFY_ANCESTOR &&
-      timeout_connection.connected())
-    {
-      timeout_connection.disconnect();
-    }
-  TRACE_EXIT();
-  return false;
-}
-
-bool
-MainWindow::win32_on_hide_timer()
-{
-  win32_tray_menu->popdown();
-
-  return false;
-}
-
 #endif
 
 void
 MainWindow::get_start_position(int &x, int &y, int &head)
 {
   TRACE_ENTER("MainWindow::get_start_position");
-  bool b;
   // FIXME: Default to right-bottom instead of 256x256
-  ConfiguratorInterface *cfg = CoreFactory::get_configurator();
-  b = cfg->get_value(CFG_KEY_MAIN_WINDOW_X, &x);
-  if (! b)
-    {
-      x = 256;
-    }
-  b = cfg->get_value(CFG_KEY_MAIN_WINDOW_Y, &y);
-  if (! b)
-    {
-      y = 256;
-    }
-  b = cfg->get_value(CFG_KEY_MAIN_WINDOW_HEAD, &head);
-  if (! b)
-    {
-      head = 0;
-    }
-
+  IConfigurator *cfg = CoreFactory::get_configurator();
+  cfg->get_value_default(CFG_KEY_MAIN_WINDOW_X, &x, 256);
+  cfg->get_value_default(CFG_KEY_MAIN_WINDOW_Y, &y, 256);
+  cfg->get_value_default(CFG_KEY_MAIN_WINDOW_HEAD, &head, 0);
   if (head < 0)
     {
       head = 0;
     }
-        
   TRACE_MSG(x << " " << y << " " << head);
-
   TRACE_EXIT();
 }
 
@@ -939,7 +602,7 @@ MainWindow::set_start_position(int x, int y, int head)
 {
   TRACE_ENTER_MSG("MainWindow::set_start_position",
                   x << " " << y << " " << head);
-  ConfiguratorInterface *cfg = CoreFactory::get_configurator();
+  IConfigurator *cfg = CoreFactory::get_configurator();
   cfg->set_value(CFG_KEY_MAIN_WINDOW_X, x);
   cfg->set_value(CFG_KEY_MAIN_WINDOW_Y, y);
   cfg->set_value(CFG_KEY_MAIN_WINDOW_HEAD, head);
@@ -1020,8 +683,20 @@ MainWindow::locate_window(GdkEventConfigure *event)
   TRACE_ENTER("MainWindow::locate_window");
   int x, y;
   int width, height;
-  
-  if (event == NULL)
+
+#ifndef WIN32
+  // Returns bogus results on windows...sometime.
+  if (event != NULL)
+    {
+      x = event->x;
+      y = event->y;
+      width = event->width;
+      height = event->height;
+
+      TRACE_MSG("main window2 = " << x << " " << y);
+    }
+  else
+#endif    
     {
       get_position(x, y);
 
@@ -1029,15 +704,11 @@ MainWindow::locate_window(GdkEventConfigure *event)
       on_size_request(&req);
       width = req.width;
       height = req.height;
-    }
-  else
-    {
-      x = event->x;
-      y = event->y;
-      width = event->width;
-      height = event->height;
+
+      TRACE_MSG("main window1 = " << x << " " << y);
     }
 
+ 
   TRACE_MSG("main window = " << x << " " << y);
 
   if (x <= 0 && y <= 0)
@@ -1131,3 +802,15 @@ MainWindow::relocate_window(int width, int height)
   
   TRACE_EXIT();
 }
+
+#ifdef WIN32
+
+LRESULT CALLBACK
+MainWindow::win32_window_proc(HWND hwnd, UINT uMsg, WPARAM wParam,
+                              LPARAM lParam)
+{
+  TRACE_ENTER("MainWindow::win32_window_proc");
+  TRACE_EXIT();
+  return DefWindowProc(hwnd, uMsg, wParam, lParam);
+}
+#endif
