@@ -1,6 +1,6 @@
 // Menus.cc --- Timer info Window
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: Menus.cc,v 1.19 2006/04/25 21:27:53 rcaelers Exp $";
+static const char rcsid[] = "$Id: Menus.cc 1115 2007-02-04 13:30:34Z rcaelers $";
 
 #include "preinclude.h"
 
@@ -24,12 +24,15 @@ static const char rcsid[] = "$Id: Menus.cc,v 1.19 2006/04/25 21:27:53 rcaelers E
 
 #include "nls.h"
 #include "debug.hh"
+#include "credits.h"
 
 #include <unistd.h>
 #include <iostream>
 
+#include <gtk/gtkmenu.h>
 #include <gtkmm/menu.h>
 #include <gtkmm/stock.h>
+#include <gtkmm/aboutdialog.h>
 
 #include "Menus.hh"
 #include "TimeBar.hh"
@@ -39,22 +42,20 @@ static const char rcsid[] = "$Id: Menus.cc,v 1.19 2006/04/25 21:27:53 rcaelers E
 
 #include "PreferencesDialog.hh"
 #include "StatisticsDialog.hh"
-#include "StatisticsInterface.hh"
+#include "IStatistics.hh"
 
 #include "CoreFactory.hh"
-#include "CoreInterface.hh"
-#include "TimerInterface.hh"
-#include "ConfiguratorInterface.hh"
+#include "ICore.hh"
+#include "ITimer.hh"
+#include "IConfigurator.hh"
 
 #ifdef HAVE_DISTRIBUTION
-#include "DistributionManagerInterface.hh"
+#include "IDistributionManager.hh"
 #include "NetworkJoinDialog.hh"
 #include "NetworkLogDialog.hh"
 #endif
 #ifdef HAVE_GNOME
-#include "AppletWindow.hh"
-#else
-#include "gnome-about.h"
+#include "GnomeAppletWindow.hh"
 #endif
 #include "MainWindow.hh"
 
@@ -65,10 +66,10 @@ static const char rcsid[] = "$Id: Menus.cc,v 1.19 2006/04/25 21:27:53 rcaelers E
 
 #ifdef WIN32
 #include <gdk/gdkwin32.h>
-#include "TimerBoxAppletView.hh"
+#include "W32AppletWindow.hh"
 #endif
 
-Menus *Menus::instance = NULL;
+Menus *Menus::instance = 0;
 
 #ifdef WIN32
 enum
@@ -88,13 +89,14 @@ enum
 };
 #endif
 
+
 //! Constructor.
 /*!
  *  \param gui the main GUI entry point.
  *  \param control Interface to the controller.
  */
 Menus::Menus() :
-#ifdef HAVE_GNOME  
+#if defined(HAVE_GNOME) || defined(WIN32)
   applet_window(NULL),
 #endif
 #ifdef HAVE_DISTRIBUTION
@@ -108,12 +110,17 @@ Menus::Menus() :
 #endif
   main_window(NULL)
 {
+  assert(instance == 0);
+  instance = this;
   gui = GUI::get_instance();
 
-  for (int i = 0; i < MAX_CHECKMENUS; i++)
+  for (int k = 0; k < MENU_SIZEOF; k++)
     {
-      main_window_check_menus[i] = NULL;
-      tray_check_menus[i] = NULL;
+      menus[k] = NULL;
+      for (int i = 0; i < MENUSYNC_SIZEOF; i++)
+        {
+          sync_menus[k][i] = NULL;
+        }
     }
 }
 
@@ -122,42 +129,67 @@ Menus::Menus() :
 Menus::~Menus()
 {
   TRACE_ENTER("Menus::~Menus");
+  instance = 0;
+
+  for (int k = 0; k < MENU_SIZEOF; k++)
+    {
+      delete menus[k];
+      menus[k] = NULL;
+    }
+  
   TRACE_EXIT();
 }
 
 
-Gtk::Menu *
-Menus::create_main_window_menu()
+void
+Menus::create_menu(MenuKind kind)
 {
-  Gtk::Menu *menu = manage(create_menu(main_window_check_menus)); // FIXME: leak
-    
+  if (! menus[kind])
+    {
+      menus[kind] = manage(create_menu(kind, sync_menus[kind]));
+
 #ifdef HAVE_DISTRIBUTION
-  main_window_check_menus[3]->signal_toggled().connect(MEMBER_SLOT(*this,
-                                                                  &Menus::on_menu_network_log_main_window));
-#endif  
 
-  return menu;
-}
+      switch (kind)
+        {
+        case MENU_MAINWINDOW:
+          sync_menus[kind][MENUSYNC_SHOW_LOG]->signal_toggled().
+            connect(MEMBER_SLOT(*this, &Menus::on_menu_network_log_main_window));
+          break;
+      
+        case MENU_APPLET:
+          sync_menus[kind][MENUSYNC_SHOW_LOG]->signal_toggled().
+            connect(MEMBER_SLOT(*this, &Menus::on_menu_network_log_tray));
+          break;
 
-
-Gtk::Menu *
-Menus::create_tray_menu()
-{
-  Gtk::Menu *menu = manage(create_menu(tray_check_menus));
-#ifdef HAVE_DISTRIBUTION
-  tray_check_menus[3]->signal_toggled().connect(MEMBER_SLOT(*this,
-                                                           &Menus::on_menu_network_log_tray));
+        default:
+          break;
+        }
 #endif
-
-  return menu;
+      if (kind == MENU_APPLET)
+        {
+          resync_applet();
+        }
+    }
 }
 
+void
+Menus::popup(const MenuKind kind,
+             const guint button,
+             const guint activate_time)
+{
+  Gtk::Menu *pop_menu = menus[kind];
+  if (pop_menu)
+    {
+      pop_menu->popup(button, activate_time);
+    }
+}
 
 //! Create the popup-menu
 Gtk::Menu *
-Menus::create_menu(Gtk::CheckMenuItem *check_menus[4])
+Menus::create_menu(MenuKind kind, Gtk::CheckMenuItem *check_menus[MENUSYNC_SIZEOF])
 {
-  TRACE_ENTER("Menus::create_menu");
+  TRACE_ENTER_MSG("Menus::create_menu", kind);
   Gtk::Menu *pop_menu = manage(new Gtk::Menu());
   
   Gtk::Menu::MenuList &menulist = pop_menu->items();
@@ -170,31 +202,51 @@ Menus::create_menu(Gtk::CheckMenuItem *check_menus[4])
   mode_menu_item->set_submenu(*mode_menu);
   mode_menu_item->show();
 
-  Gtk::RadioMenuItem::Group gr;
-  // Suspend menu item.
-  Gtk::RadioMenuItem *normal_menu_item
-    = manage(new Gtk::RadioMenuItem(gr, _("_Normal"), true));
-  normal_menu_item->signal_toggled().connect(bind(MEMBER_SLOT(*this, &Menus::on_menu_normal_menu), normal_menu_item));
-  normal_menu_item->show();
-  modemenulist.push_back(*normal_menu_item);
 
-  // Suspend menu item.
-  Gtk::RadioMenuItem *suspend_menu_item
-    = manage(new Gtk::RadioMenuItem(gr, _("_Suspended"), true));
-  suspend_menu_item->signal_toggled().connect(bind(MEMBER_SLOT(*this, &Menus::on_menu_suspend_menu), suspend_menu_item));
-  suspend_menu_item->show();
-  modemenulist.push_back(*suspend_menu_item);
+  // Operation mode
+  {
+    const char *modes_str[] =
+      {
+        "_Normal",
+        "_Suspended",
+        "Q_uiet",
+      };
+    OperationMode modes[] =
+      {
+        OPERATION_MODE_NORMAL,
+        OPERATION_MODE_SUSPENDED,
+        OPERATION_MODE_QUIET
+      };
+    typedef void (Menus::*ModeFunc)(Gtk::CheckMenuItem *);
+    ModeFunc modes_func[] =
+      {
+        &Menus::on_menu_normal_menu,
+        &Menus::on_menu_suspend_menu,
+        &Menus::on_menu_quiet_menu
+      };
+    
+    ICore *core = CoreFactory::get_core();
+    OperationMode mode = core->get_operation_mode();      
 
-  // Quiet menu item.
-  Gtk::RadioMenuItem *quiet_menu_item
-    = manage(new Gtk::RadioMenuItem(gr, _("Q_uiet"), true));
-  quiet_menu_item->signal_toggled().connect(bind(MEMBER_SLOT(*this, &Menus::on_menu_quiet_menu),quiet_menu_item));
-  quiet_menu_item->show();
-  modemenulist.push_back(*quiet_menu_item);
+    Gtk::RadioMenuItem::Group gr;
 
-  check_menus[0] = normal_menu_item;
-  check_menus[1] = suspend_menu_item;
-  check_menus[2] = quiet_menu_item;
+    assert(sizeof(modes)/sizeof(modes[0]) == OPERATION_MODE_SIZEOF);
+    for (size_t i = 0; i < OPERATION_MODE_SIZEOF; i++)
+      {
+        Gtk::RadioMenuItem *mode_menu_item
+          = manage(new Gtk::RadioMenuItem(gr, _(modes_str[i]), true));
+        mode_menu_item->show();
+        modemenulist.push_back(*mode_menu_item);
+        mode_menu_item->set_active(mode == modes[i]);
+        check_menus[i] = mode_menu_item;
+      }
+    for (size_t i = 0; i < OPERATION_MODE_SIZEOF; i++)
+      {
+        check_menus[i]->signal_toggled()
+          .connect(bind(MEMBER_SLOT(*this, modes_func[i]),
+                        check_menus[i]));
+      }
+  }
 
 #ifdef HAVE_DISTRIBUTION
   // Distribution menu
@@ -224,18 +276,16 @@ Menus::create_menu(Gtk::CheckMenuItem *check_menus[4])
   distr_log_menu_item->show();
   distr_menu_list.push_back(*distr_log_menu_item);
 
-  check_menus[3] = distr_log_menu_item;
+  check_menus[MENUSYNC_SHOW_LOG] = distr_log_menu_item;
 #endif
   
   // FIXME: add separators, etc...
-#ifndef WIN32
-  if (check_menus == tray_check_menus)
+  if (kind == MENU_APPLET)
     {
       menulist.push_front(Gtk::Menu_Helpers::StockMenuElem
                           (Gtk::Stock::OPEN,
                            MEMBER_SLOT(*this, &Menus::on_menu_open_main_window)));
     }
-#endif
   
   menulist.push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::PREFERENCES,
                                                       MEMBER_SLOT(*this, &Menus::on_menu_preferences)));
@@ -292,6 +342,14 @@ Menus::create_menu(Gtk::CheckMenuItem *check_menus[4])
   menulist.push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::QUIT,
                                                  MEMBER_SLOT(*this, &Menus::on_menu_quit)));
 
+
+#ifdef WIN32
+  if (kind == MENU_APPLET)
+    {
+      win32_popup_hack_connect(pop_menu);
+    }
+#endif  
+
   TRACE_EXIT();
   return pop_menu;
 }
@@ -300,27 +358,30 @@ Menus::create_menu(Gtk::CheckMenuItem *check_menus[4])
 void
 Menus::sync_mode_menu(int mode)
 {
-  TRACE_ENTER("sync_mode_menu");
-
   // Ugh, isn't there an other way to prevent endless signal loops?
   static bool syncing = false;
+
+  TRACE_ENTER_MSG("Menus::sync_mode_menu", mode << " " << syncing);
   if (syncing)
     return;
   syncing = true;
 
-  if (main_window_check_menus[mode] != NULL && !main_window_check_menus[mode]->get_active())
+  for (int k = MENU_MAINWINDOW; k < MENU_SIZEOF; k++)
     {
-      TRACE_MSG("setting active");
-      main_window_check_menus[mode]->set_active(true);
+      if (sync_menus[k][mode] != NULL && !sync_menus[k][mode]->get_active())
+        {
+          TRACE_MSG("setting active " << k <<" " << mode);
+          sync_menus[k][mode]->set_active(true);
+        }
+ 
     }
-
-  if (tray_check_menus[mode] != NULL && !tray_check_menus[mode]->get_active())
-    tray_check_menus[mode]->set_active(true);
   
 #if defined(HAVE_GNOME)
-  if (applet_window != NULL)
+  GnomeAppletWindow *aw = static_cast<GnomeAppletWindow*>(applet_window);
+  if (aw != NULL)
     {
-      applet_window->set_menu_active(mode, true);
+      TRACE_MSG("setting gnome active " << mode);
+      aw->set_menu_active(mode, true);
     }
 #elif defined(WIN32)
   resync_applet();
@@ -332,29 +393,28 @@ Menus::sync_mode_menu(int mode)
 }
 
 void
-Menus::sync_tray_menu(bool active)
+Menus::sync_log_menu(bool active)
 {
-  TRACE_ENTER("sync_tray_menu");
+  TRACE_ENTER("Menus::sync_log_menu");
 
   static bool syncing = false;
   if (syncing)
     return;
   syncing = true;
 
-  if (main_window_check_menus[3] != NULL)
+  for (int k = 0; k < MENU_SIZEOF; k++)
     {
-      main_window_check_menus[3]->set_active(active);
-    }
-
-  if (tray_check_menus[3] != NULL)
-    {
-      tray_check_menus[3]->set_active(active);
+      if (sync_menus[k][MENUSYNC_SHOW_LOG] != NULL)
+        {
+          sync_menus[k][MENUSYNC_SHOW_LOG]->set_active(active);
+        }
     }
   
 #if defined(HAVE_GNOME)
-  if (applet_window != NULL)
+  GnomeAppletWindow *aw = static_cast<GnomeAppletWindow*>(applet_window);
+  if (aw != NULL)
     {
-      applet_window->set_menu_active(3, active);
+      aw->set_menu_active(MENUSYNC_SHOW_LOG, active);
     }
 #elif defined(WIN32)
   resync_applet();
@@ -369,93 +429,115 @@ Menus::sync_tray_menu(bool active)
 void
 Menus::resync_applet()
 {
+  ICore *core = CoreFactory::get_core();
+  OperationMode mode = core->get_operation_mode();
+  
+  for (int k = MENU_MAINWINDOW; k < MENU_SIZEOF; k++)
+    {
+      if (sync_menus[k][mode] != NULL && !sync_menus[k][mode]->get_active())
+        {
+          sync_menus[k][mode]->set_active(true);
+        }
+    }
+  
+#if defined(HAVE_DISTRIBUTION)
+  bool network_log_active = network_log_dialog != NULL;
+  for (int k = 0; k < MENU_SIZEOF; k++)
+    {
+      if (sync_menus[k][MENUSYNC_SHOW_LOG] != NULL)
+        {
+          sync_menus[k][MENUSYNC_SHOW_LOG]->set_active(network_log_active);
+        }
+    }
+#endif
+      
 #if defined(HAVE_GNOME)
-  if (applet_window != NULL)
+  GnomeAppletWindow *aw = static_cast<GnomeAppletWindow*>(applet_window);
+  if (aw != NULL)
     {
-      CoreInterface *core = CoreFactory::get_core();
-      OperationMode mode = core->get_operation_mode();      
       switch(mode)
         {
         case OPERATION_MODE_NORMAL:
-          applet_window->set_menu_active(0, true);
+          aw->set_menu_active(MENUSYNC_MODE_NORMAL, true);
           break;
         case OPERATION_MODE_SUSPENDED:
-          applet_window->set_menu_active(1, true);
+          aw->set_menu_active(MENUSYNC_MODE_SUSPENDED, true);
           break;
         case OPERATION_MODE_QUIET:
-          applet_window->set_menu_active(2, true);
+          aw->set_menu_active(MENUSYNC_MODE_QUIET, true);
           break;
         default:
           break;
         }
 #if defined(HAVE_DISTRIBUTION)
-      applet_window->set_menu_active(3, network_log_dialog != NULL);
+      bool network_log_active = network_log_dialog != NULL;
+      aw->set_menu_active(MENUSYNC_SHOW_LOG, network_log_dialog);
+      
 #endif
     }
-#elif defined(WIN32)
-  if (applet_window != NULL && main_window != NULL )
-    {
-      CoreInterface *core = CoreFactory::get_core();
 
+#elif defined(WIN32)
+  if (applet_window != NULL && main_window != NULL)
+    {
       HWND cmd_win = (HWND) GDK_WINDOW_HWND( main_window
                                              ->Gtk::Widget::gobj()->window);
-      applet_window->init_menu(cmd_win);
+      W32AppletWindow *w32aw = static_cast<W32AppletWindow*>(applet_window);
+      w32aw->init_menu(cmd_win);
 
-      applet_window->add_menu(_("Preferences"), MENU_COMMAND_PREFERENCES, 0);
-      applet_window->add_menu(_("_Rest break"), MENU_COMMAND_REST_BREAK, 0);
-      applet_window->add_menu(_("Exercises"), MENU_COMMAND_EXERCISES, 0);
+      w32aw->add_menu(_("Preferences"), MENU_COMMAND_PREFERENCES, 0);
+      w32aw->add_menu(_("_Rest break"), MENU_COMMAND_REST_BREAK, 0);
+      w32aw->add_menu(_("Exercises"), MENU_COMMAND_EXERCISES, 0);
 
 
-      applet_window->add_menu(_("_Normal"), MENU_COMMAND_MODE_NORMAL,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP
-                              |(core->get_operation_mode()
-                                == OPERATION_MODE_NORMAL
-                                ? TimerBoxAppletView::MENU_FLAG_SELECTED
-                                : 0));
-      applet_window->add_menu(_("_Suspended"), MENU_COMMAND_MODE_SUSPENDED,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP
-                              |(core->get_operation_mode()
-                                == OPERATION_MODE_SUSPENDED
-                                ? TimerBoxAppletView::MENU_FLAG_SELECTED
-                                : 0));
-      applet_window->add_menu(_("Q_uiet"), MENU_COMMAND_MODE_QUIET,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP
-                              |(core->get_operation_mode()
-                                == OPERATION_MODE_QUIET
-                                ? TimerBoxAppletView::MENU_FLAG_SELECTED
-                                : 0));
-      applet_window->add_menu(_("_Mode"), 0, 0);
+      w32aw->add_menu(_("_Normal"), MENU_COMMAND_MODE_NORMAL,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP
+                      |(core->get_operation_mode()
+                        == OPERATION_MODE_NORMAL
+                        ? W32AppletWindow::MENU_FLAG_SELECTED
+                        : 0));
+      w32aw->add_menu(_("_Suspended"), MENU_COMMAND_MODE_SUSPENDED,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP
+                      |(core->get_operation_mode()
+                        == OPERATION_MODE_SUSPENDED
+                        ? W32AppletWindow::MENU_FLAG_SELECTED
+                        : 0));
+      w32aw->add_menu(_("Q_uiet"), MENU_COMMAND_MODE_QUIET,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP
+                      |(core->get_operation_mode()
+                        == OPERATION_MODE_QUIET
+                        ? W32AppletWindow::MENU_FLAG_SELECTED
+                        : 0));
+      w32aw->add_menu(_("_Mode"), 0, 0);
 
 #ifdef HAVE_DISTRIBUTION
-      applet_window->add_menu(_("_Connect"), MENU_COMMAND_NETWORK_CONNECT,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP);
-      applet_window->add_menu(_("_Disconnect"),
-                              MENU_COMMAND_NETWORK_DISCONNECT,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP);
-      applet_window->add_menu(_("_Reconnect"), MENU_COMMAND_NETWORK_RECONNECT,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP);
-      applet_window->add_menu(_("Show _log"), MENU_COMMAND_NETWORK_LOG,
-                              TimerBoxAppletView::MENU_FLAG_TOGGLE
-                              |TimerBoxAppletView::MENU_FLAG_POPUP
-                              |(network_log_dialog != NULL
-                                ? TimerBoxAppletView::MENU_FLAG_SELECTED
-                                : 0));
-      applet_window->add_menu(_("_Network"), 0, 0);
+      w32aw->add_menu(_("_Connect"), MENU_COMMAND_NETWORK_CONNECT,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP);
+      w32aw->add_menu(_("_Disconnect"),
+                      MENU_COMMAND_NETWORK_DISCONNECT,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP);
+      w32aw->add_menu(_("_Reconnect"), MENU_COMMAND_NETWORK_RECONNECT,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP);
+      w32aw->add_menu(_("Show _log"), MENU_COMMAND_NETWORK_LOG,
+                      W32AppletWindow::MENU_FLAG_TOGGLE
+                      |W32AppletWindow::MENU_FLAG_POPUP
+                      |(network_log_dialog != NULL
+                        ? W32AppletWindow::MENU_FLAG_SELECTED
+                        : 0));
+      w32aw->add_menu(_("_Network"), 0, 0);
 #endif
-      applet_window->add_menu(_("Statistics"), MENU_COMMAND_STATISTICS, 0);
-      applet_window->add_menu(_("About..."), MENU_COMMAND_ABOUT, 0);
+      w32aw->add_menu(_("Statistics"), MENU_COMMAND_STATISTICS, 0);
+      w32aw->add_menu(_("About..."), MENU_COMMAND_ABOUT, 0);
     }
 #endif
 
 }
 
-
 void
 Menus::on_menu_open_main_window()
 {
@@ -468,9 +550,9 @@ void
 Menus::on_menu_quit()
 {
   TRACE_ENTER("Menus::on_menu_quit");
-
+  
   gui->terminate();
-
+  
   TRACE_EXIT();
 }
 
@@ -483,15 +565,21 @@ Menus::on_menu_restbreak_now()
 }
 
 
+void
+Menus::set_operation_mode(OperationMode m)
+{
+  ICore *core = CoreFactory::get_core();
+  core->set_operation_mode(m);
+  sync_mode_menu(m);
+}
+
+
 //! User requested immediate restbreak.
 void
 Menus::on_menu_quiet()
 {
   TRACE_ENTER("Menus::on_menu_quiet");
-
-  CoreInterface *core = CoreFactory::get_core();
-  core->set_operation_mode(OPERATION_MODE_QUIET);
-  sync_mode_menu(2);
+  set_operation_mode(OPERATION_MODE_QUIET);
   TRACE_EXIT();
 }
 
@@ -502,10 +590,7 @@ void
 Menus::on_menu_suspend()
 {
   TRACE_ENTER("Menus::on_menu_suspend");
-
-  CoreInterface *core = CoreFactory::get_core();
-  core->set_operation_mode(OPERATION_MODE_SUSPENDED);
-  sync_mode_menu(1);
+  set_operation_mode(OPERATION_MODE_SUSPENDED);
   TRACE_EXIT();
 }
 
@@ -513,9 +598,10 @@ Menus::on_menu_suspend()
 void
 Menus::on_menu_normal_menu(Gtk::CheckMenuItem *menu)
 {
-  TRACE_ENTER("Menus::on_menu_normal");
+  TRACE_ENTER("Menus::on_menu_normal_menu");
   if (menu != NULL && menu->get_active())
     {
+      TRACE_MSG("active");
       on_menu_normal();
     }
   TRACE_EXIT();
@@ -526,10 +612,11 @@ Menus::on_menu_normal_menu(Gtk::CheckMenuItem *menu)
 void
 Menus::on_menu_quiet_menu(Gtk::CheckMenuItem *menu)
 {
-  TRACE_ENTER("Menus::on_menu_quiet");
-
+  TRACE_ENTER("Menus::on_menu_quiet_menu");
+  
   if (menu != NULL && menu->get_active())
     {
+      TRACE_MSG("active");
       on_menu_quiet();
     }
   TRACE_EXIT();
@@ -541,13 +628,14 @@ Menus::on_menu_quiet_menu(Gtk::CheckMenuItem *menu)
 void
 Menus::on_menu_suspend_menu(Gtk::CheckMenuItem *menu)
 {
-  TRACE_ENTER("Menus::on_menu_suspend");
-
+  TRACE_ENTER("Menus::on_menu_suspend_menu");
+  
   if (menu != NULL && menu->get_active())
     {
+      TRACE_MSG("active");
       on_menu_suspend();
     }
-
+  
   TRACE_EXIT();
 }
 
@@ -556,9 +644,7 @@ void
 Menus::on_menu_normal()
 {
   TRACE_ENTER("Menus::on_menu_normal");
-  CoreInterface *core = CoreFactory::get_core();
-  core->set_operation_mode(OPERATION_MODE_NORMAL);
-  sync_mode_menu(0);
+  set_operation_mode(OPERATION_MODE_NORMAL);
   TRACE_EXIT();
 }
 
@@ -568,10 +654,10 @@ Menus::on_menu_normal()
 void
 Menus::on_test_me()
 { 
-  CoreInterface *core = CoreFactory::get_core();
-  StatisticsInterface *stats = core->get_statistics();
+  ICore *core = CoreFactory::get_core();
+  IStatistics *stats = core->get_statistics();
   stats->dump();
-
+  
   core->test_me();
 }
 #endif
@@ -615,7 +701,7 @@ Menus::on_menu_preferences()
     {
       preferences_dialog = new PreferencesDialog();
       preferences_dialog->signal_response().connect(MEMBER_SLOT(*this, &Menus::on_preferences_response));
-          
+      
       preferences_dialog->run();
     }
   else
@@ -634,7 +720,7 @@ Menus::on_menu_exercises()
     {
       exercises_dialog = new ExercisesDialog();
       exercises_dialog->signal_response().connect(MEMBER_SLOT(*this, &Menus::on_exercises_response));
-          
+      
       exercises_dialog->run();
     }
   else
@@ -651,7 +737,7 @@ Menus::on_exercises_response(int response)
   
   assert(exercises_dialog != NULL);
   exercises_dialog->hide_all();
-
+  
   delete exercises_dialog;
   exercises_dialog = NULL;
 }
@@ -665,13 +751,13 @@ Menus::on_menu_statistics()
 {
   if (statistics_dialog == NULL)
     {
-      CoreInterface *core = CoreFactory::get_core();
-      StatisticsInterface *stats = core->get_statistics();
+      ICore *core = CoreFactory::get_core();
+      IStatistics *stats = core->get_statistics();
       stats->update();
       
       statistics_dialog = new StatisticsDialog();
       statistics_dialog->signal_response().connect(MEMBER_SLOT(*this, &Menus::on_statistics_response));
-          
+      
       statistics_dialog->run();
     }
   else
@@ -686,42 +772,43 @@ Menus::on_menu_statistics()
 void
 Menus::on_menu_about()
 {
-  const gchar *authors[] = {
-   "Rob Caelers <robc@krandor.org>",
-   "Raymond Penners <raymond@dotsphinx.com>",
-   NULL
-  };
-  const gchar *translators = 
-    "Raymond Penners <raymond@dotsphinx.com>\n"
-    "Johannes Rohr <j.rohr@comlink.apc.org>\n"
-    "Christian Vejlbo <christian@vejlbo.dk>\n"
-    "Mikolaj Machowski <mikmach@wp.pl>\n"
-    "Pablo Rodriguez\n"
-    "Rex Tsai <chihchun@linux.org.tw>\n"
-    "Sergey Kirkinsky <ksa@pfr.altai.ru>\n"
-    "Thomas Basset <thomas.basset@netcourrier.com>\n"
-    "Benjamin Siband <translations@wordinfrench.com>\n"
-    "Claudio Ferreira Filho <filhocf@yahoo.com.br>\n"
-    "Morten Lunde <morten.lunde@broadpark.no>\n"
-    "Juraj Kubelka <Juraj.Kubelka@email.cz>\n"
-    "Artūras Šlajus <x11@h2o.sky.lt>\n"
-    "Haggai Eran <he3@bezeqint.net>\n"
-    "Jordi Mallach <jordi@sindominio.net>\n"
-    "Daniel Nylander <info@danielnylander.se>\n";
-
   string icon = Util::complete_directory("workrave.png",
                                          Util::SEARCH_PATH_IMAGES);
-  GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file(icon.c_str(), NULL); 
-  gtk_widget_show (gnome_about_new
-                   ("Workrave", VERSION,
-                    "Copyright 2001-2006 Rob Caelers & Raymond Penners",
-                    _("This program assists in the prevention and recovery"
-                      " of Repetitive Strain Injury (RSI)."),
-                    (const gchar **) authors,
-                    (const gchar **) NULL,
-                    translators,
-                    pixbuf));
-  g_object_unref(pixbuf);
+  Glib::RefPtr<Gdk::Pixbuf> pixbuf;
+  
+  try
+    {
+      pixbuf = Gdk::Pixbuf::create_from_file(icon);
+    }
+  catch (...)
+    {
+    }
+  
+  Gtk::AboutDialog about;
+
+  about.set_name("Workrave");
+  about.set_authors(workrave_authors);
+  about.set_copyright(workrave_copyright);
+  about.set_comments(_("This program assists in the prevention and recovery"
+                       " of Repetitive Strain Injury (RSI)."));
+  about.set_logo(pixbuf);
+  about.set_translator_credits(workrave_translators);
+  about.set_version(VERSION);
+  about.set_website("http://www.workrave.org/");
+  about.set_website_label("www.workrave.org");
+
+  about.run();
+  
+//   gtk_widget_show (gnome_about_new
+//                    ("Workrave", VERSION,
+//                     "Copyright 2001-2006 Rob Caelers & Raymond Penners",
+//                     _("This program assists in the prevention and recovery"
+//                       " of Repetitive Strain Injury (RSI)."),
+//                     (const gchar **) authors,
+//                     (const gchar **) NULL,
+//                     translators,
+//                     pixbuf));
+//   g_object_unref(pixbuf);
 }
 
 
@@ -750,17 +837,17 @@ Menus::on_network_join_response(int response)
   
   assert(network_join_dialog != NULL);
   network_join_dialog->hide_all();
-
+  
   if (response == Gtk::RESPONSE_OK)
     {
-      CoreInterface *core = CoreFactory::get_core();
-      DistributionManagerInterface *dist_manager
+      ICore *core = CoreFactory::get_core();
+      IDistributionManager *dist_manager
         = core->get_distribution_manager();
       std::string peer = network_join_dialog->get_connect_url();
       dist_manager->connect(peer);
       CoreFactory::get_configurator()->save();
     }
-
+  
   delete network_join_dialog;
   network_join_dialog = NULL;
 }
@@ -770,8 +857,8 @@ void
 Menus::on_menu_network_leave()
 {
 #ifdef HAVE_DISTRIBUTION
-  CoreInterface *core = CoreFactory::get_core();
-  DistributionManagerInterface *dist_manager = core->get_distribution_manager();
+  ICore *core = CoreFactory::get_core();
+  IDistributionManager *dist_manager = core->get_distribution_manager();
   if (dist_manager != NULL)
     {
       dist_manager->disconnect_all();
@@ -783,8 +870,8 @@ void
 Menus::on_menu_network_reconnect()
 {
 #ifdef HAVE_DISTRIBUTION
-  CoreInterface *core = CoreFactory::get_core();
-  DistributionManagerInterface *dist_manager = core->get_distribution_manager();
+  ICore *core = CoreFactory::get_core();
+  IDistributionManager *dist_manager = core->get_distribution_manager();
   if (dist_manager != NULL)
     {
       dist_manager->reconnect_all();
@@ -797,29 +884,29 @@ Menus::on_menu_network_log(bool active)
 {
 #ifdef HAVE_DISTRIBUTION
   TRACE_ENTER("Menus::on_menu_network_log");
-
+  
   if (active)
     {
       if (network_log_dialog == NULL)
         {
           network_log_dialog = new NetworkLogDialog();
-          network_log_dialog->signal_response().connect(MEMBER_SLOT(*this, &Menus::on_network_log_response));
+          network_log_dialog->signal_response().
+            connect(MEMBER_SLOT(*this, &Menus::on_network_log_response));
+          
+          sync_log_menu(active);
           
-          sync_tray_menu(active);
-
           network_log_dialog->run();
         }
-
     }
   else if (network_log_dialog != NULL)
     {
       network_log_dialog->hide_all();
       delete network_log_dialog;
       network_log_dialog = NULL;
-      sync_tray_menu(active);
+      sync_log_menu(active);
     }
-
-
+  
+  
   TRACE_EXIT();
 #endif
 }
@@ -831,13 +918,13 @@ void
 Menus::on_menu_network_log_tray()
 {
   TRACE_ENTER("Menus::on_menu_network_log_tray");
-
-  if (tray_check_menus[3] != NULL)
+  
+  if (sync_menus[MENU_APPLET][MENUSYNC_SHOW_LOG] != NULL)
     {
-      bool active = tray_check_menus[3]->get_active();
+      bool active = sync_menus[MENU_APPLET][MENUSYNC_SHOW_LOG]->get_active();
       on_menu_network_log(active);
     }
-
+  
   TRACE_EXIT();
 }
 
@@ -845,13 +932,13 @@ void
 Menus::on_menu_network_log_main_window()
 {
   TRACE_ENTER("Menus::on_menu_network_log");
-
-  if (main_window_check_menus[3] != NULL)
+  
+  if (sync_menus[MENU_MAINWINDOW][MENUSYNC_SHOW_LOG] != NULL)
     {
-      bool active = main_window_check_menus[3]->get_active();
+      bool active = sync_menus[MENU_MAINWINDOW][MENUSYNC_SHOW_LOG]->get_active();
       on_menu_network_log(active);
     }
-
+  
   TRACE_EXIT();
 }
 
@@ -859,12 +946,12 @@ void
 Menus::on_network_log_response(int response)
 {
   (void) response;
-
+  
   assert(network_log_dialog != NULL);
   
   network_log_dialog->hide_all();
-
-  sync_tray_menu(false);
+  
+  sync_log_menu(false);
   // done by gtkmm ??? delete network_log_dialog;
   network_log_dialog = NULL;
 }
@@ -878,7 +965,7 @@ Menus::on_statistics_response(int response)
   
   assert(statistics_dialog != NULL);
   statistics_dialog->hide_all();
-
+  
   delete statistics_dialog;
   statistics_dialog = NULL;
 }
@@ -891,9 +978,9 @@ Menus::on_preferences_response(int response)
   
   assert(preferences_dialog != NULL);
   preferences_dialog->hide_all();
-
+  
   CoreFactory::get_configurator()->save();
-
+  
   delete preferences_dialog;
   preferences_dialog = NULL;
 }
@@ -945,3 +1032,68 @@ Menus::on_applet_command(short cmd)
 }
 
 #endif
+
+#if defined(HAVE_GNOME) || defined(WIN32)
+void
+Menus::set_applet_window(AppletWindow *applet)
+{
+  applet_window = applet;
+  resync_applet();
+}
+#endif
+
+
+#ifdef WIN32
+// /* Taken from Gaim. needs to be gtkmm-ified. */
+// /* This is a workaround for a bug in windows GTK+. Clicking outside of the
+//    menu does not get rid of it, so instead we get rid of it as soon as the
+//    pointer leaves the menu. */
+
+void
+Menus::win32_popup_hack_connect(Gtk::Menu *menu)
+{
+  GtkWidget *window = (GtkWidget*) menu->gobj();
+  // RC: FIXME: remove this c hack HACK 
+  g_signal_connect(window, "leave-notify-event",
+                   G_CALLBACK(win32_popup_hack_leave_enter), NULL);
+  g_signal_connect(window, "enter-notify-event",
+                   G_CALLBACK(win32_popup_hack_leave_enter), NULL);
+}
+
+gboolean 
+Menus::win32_popup_hack_hide(gpointer data)
+{
+  if (data != NULL)
+    {
+      gtk_menu_popdown(GTK_MENU(data));
+    }
+  return FALSE;
+}
+
+
+gboolean
+Menus::win32_popup_hack_leave_enter(GtkWidget *menu, GdkEventCrossing *event,
+                                    void *data)
+{
+  (void) data;
+  static guint hide_docklet_timer = 0;
+  if (event->type == GDK_LEAVE_NOTIFY
+      && event->detail == GDK_NOTIFY_ANCESTOR) {
+    /* Add some slop so that the menu doesn't annoyingly disappear
+       when mousing around */
+    if (hide_docklet_timer == 0) {
+      hide_docklet_timer = g_timeout_add(500, win32_popup_hack_hide, menu);
+    }
+  } else if (event->type == GDK_ENTER_NOTIFY
+             && event->detail == GDK_NOTIFY_ANCESTOR) {
+    if (hide_docklet_timer != 0) {
+      /* Cancel the hiding if we reenter */
+      
+      g_source_remove(hide_docklet_timer);
+      hide_docklet_timer = 0;
+    }
+  }
+  return FALSE;
+}
+
+#endif // WIN32
