@@ -1,6 +1,6 @@
 // PreludeWindow.cc
 //
-// Copyright (C) 2001, 2002, 2003, 2004 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -8,13 +8,13 @@
 // the Free Software Foundation; either version 2, or (at your option)
 // any later version.
 // 
-// This program is distributed in the hope that it will be useful,
+// This progr`>am is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: PreludeWindow.cc,v 1.5 2004/10/31 19:21:45 rcaelers Exp $";
+static const char rcsid[] = "$Id: PreludeWindow.cc 1109 2006-11-13 19:16:52Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -33,9 +33,9 @@ static const char rcsid[] = "$Id: PreludeWindow.cc,v 1.5 2004/10/31 19:21:45 rca
 #include "Util.hh"
 
 #include "CoreFactory.hh"
-#include "CoreInterface.hh"
+#include "ICore.hh"
 
-#include "BreakResponseInterface.hh"
+#include "IBreakResponse.hh"
 #include "PreludeWindow.hh"
 #include "WindowHints.hh"
 #include "Frame.hh"
@@ -191,7 +191,7 @@ PreludeWindow::add(Gtk::Widget& widget)
 //! Self-Destruct
 /*!
  *  This method MUST be used to destroy the objects through the
- *  PreludeWindowInterface. it is NOT possible to do a delete on
+ *  IPreludeWindow. it is NOT possible to do a delete on
  *  this interface...
  */
 void
@@ -220,15 +220,17 @@ PreludeWindow::stop()
 void
 PreludeWindow::refresh()
 {
+  char s[128] = "";
+      
   time_bar->set_progress(progress_value, progress_max_value);
 
-  string s;
   int tminus = progress_max_value - progress_value;
   if (tminus >= 0 || (tminus < 0 && flash_visible))
     {
       if (tminus < 0)
         tminus = 0;
-      s = progress_text + " " + Text::time_to_string(tminus);
+
+      sprintf(s, progress_text.c_str(), Text::time_to_string(tminus).c_str());
     }
   time_bar->set_text(s);
   time_bar->update();
@@ -245,51 +247,51 @@ PreludeWindow::set_progress(int value, int max_value)
 
 
 void
-PreludeWindow::set_progress_text(AppInterface::PreludeProgressText text)
+PreludeWindow::set_progress_text(IApp::PreludeProgressText text)
 {
   switch (text)
     {
-    case AppInterface::PROGRESS_TEXT_BREAK_IN:
-      progress_text = _("Break in");
+    case IApp::PROGRESS_TEXT_BREAK_IN:
+      progress_text = _("Break in %s");
       break;
       
-    case AppInterface::PROGRESS_TEXT_DISAPPEARS_IN:
-      progress_text = _("Disappears in");
+    case IApp::PROGRESS_TEXT_DISAPPEARS_IN:
+      progress_text = _("Disappears in %s");
       break;
       
-    case AppInterface::PROGRESS_TEXT_SILENT_IN:
-      progress_text = _("Silent in");
+    case IApp::PROGRESS_TEXT_SILENT_IN:
+      progress_text = _("Silent in %s");
       break;
     }
 }
 
 
 void
-PreludeWindow::set_stage(AppInterface::PreludeStage stage)
+PreludeWindow::set_stage(IApp::PreludeStage stage)
 {
   const char *icon = NULL;
   switch(stage)
     {
-    case AppInterface::STAGE_INITIAL:
+    case IApp::STAGE_INITIAL:
       frame->set_frame_flashing(0);
       frame->set_frame_visible(false);
       icon = "prelude-hint.png";
       break;
       
-    case AppInterface::STAGE_WARN:
+    case IApp::STAGE_WARN:
       frame->set_frame_visible(true);
       frame->set_frame_flashing(500);
       frame->set_frame_color(color_warn);
       icon = "prelude-hint-sad.png";
       break;
       
-    case AppInterface::STAGE_ALERT:
+    case IApp::STAGE_ALERT:
       frame->set_frame_flashing(500);
       frame->set_frame_color(color_alert);
       icon = "prelude-hint-sad.png";
       break;
 
-    case AppInterface::STAGE_MOVE_OUT:
+    case IApp::STAGE_MOVE_OUT:
       if (! did_avoid)
         {
           int winx, winy;
@@ -355,11 +357,14 @@ PreludeWindow::on_enter_notify_event(GdkEventCrossing *event)
 void
 PreludeWindow::avoid_pointer(int px, int py)
 {
+  TRACE_ENTER_MSG("PreludeWindow::avoid_pointer", px << " " << py);
   Glib::RefPtr<Gdk::Window> window = get_window();
     
   int winx, winy, width, height, wind;
   window->get_geometry(winx, winy, width, height, wind);
 
+  TRACE_MSG("geom" << winx << " " << winy << " " << width << " " << height << " ");
+
 #ifdef WIN32
   // This is only necessary for WIN32, since HAVE_X uses GdkEventCrossing.
   // Set gravitiy, otherwise, get_position() returns weird winy.
@@ -371,6 +376,7 @@ PreludeWindow::avoid_pointer(int px, int py)
   px += winx;
   py += winy;
 #endif  
+  TRACE_MSG("geom2" << winx << " " << winy << " " << width << " " << height << " ");
 
   int screen_height = head.get_height();
   int top_y = SCREEN_MARGIN;
@@ -404,12 +410,31 @@ PreludeWindow::avoid_pointer(int px, int py)
 bool
 PreludeWindow::on_avoid_pointer_timer()
 {
+#if 1  
+  Glib::RefPtr<Gdk::Display> display = Gdk::Display::get_default();
+  Gdk::ModifierType type;
+  int x,y;
+
+#ifdef HAVE_GTKMM24
+  if (display)
+#else
+  if (!display.is_null())
+#endif
+    {
+      display->get_pointer(x, y, type);
+    }
+
+  avoid_pointer(x, y);
+
+#else
   // gdk_window_get_pointer is not reliable.
   POINT p;
   if (GetCursorPos(&p))
     {
       avoid_pointer(p.x, p.y);
     }
+#endif
+  
   return true;
 }
 
