@@ -1,6 +1,6 @@
 // RestBreakWindow.cc --- window for the microbreak
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 //
@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: RestBreakWindow.cc,v 1.11 2005/07/06 19:21:24 rcaelers Exp $";
+static const char rcsid[] = "$Id: RestBreakWindow.cc 1109 2006-11-13 19:16:52Z rcaelers $";
 
 const int TIMEOUT = 1000;
 
@@ -41,15 +41,15 @@ const int TIMEOUT = 1000;
 #include "Util.hh"
 #include "WindowHints.hh"
 
-#include "TimerInterface.hh"
-#include "BreakInterface.hh"
-#include "BreakResponseInterface.hh"
+#include "ITimer.hh"
+#include "IBreak.hh"
+#include "IBreakResponse.hh"
 #include "GtkUtil.hh"
 #include "Frame.hh"
 
-#include "CoreInterface.hh"
+#include "ICore.hh"
 #include "CoreFactory.hh"
-#include "ActivityMonitorInterface.hh"
+#include "IActivityMonitor.hh"
 
 #ifdef HAVE_EXERCISES
 #include "Exercise.hh"
@@ -82,9 +82,14 @@ RestBreakWindow::create_gui()
 {
   // Add other widgets.
   Gtk::VBox *vbox = new Gtk::VBox(false, 6);
+
+#ifdef HAVE_EXERCISES
+  pluggable_panel = manage(new Gtk::HBox);
+#endif
+  
   vbox->pack_start(
 #ifdef HAVE_EXERCISES
-                   pluggable_panel
+                   *pluggable_panel
 #else
                    *create_info_panel()
 #endif
@@ -168,8 +173,8 @@ RestBreakWindow::draw_time_bar()
   
   timebar->set_text(s);
 
-  CoreInterface *core = CoreFactory::get_core();
-  ActivityMonitorInterface *monitor = core->get_activity_monitor();
+  ICore *core = CoreFactory::get_core();
+  IActivityMonitor *monitor = core->get_activity_monitor();
   ActivityState state = monitor->get_current_state();
   if (frame != NULL)
     {
@@ -217,11 +222,14 @@ RestBreakWindow::create_info_panel()
 void
 RestBreakWindow::clear_pluggable_panel()
 {
-  Glib::ListHandle<Gtk::Widget *> children = pluggable_panel.get_children();
+  TRACE_ENTER("RestBreakWindow::clear_pluggable_panel");
+  Glib::ListHandle<Gtk::Widget *> children = pluggable_panel->get_children();
   if (children.size() > 0)
     {
-      pluggable_panel.remove(*(*(children.begin())));
+      TRACE_MSG("Clearing");
+      pluggable_panel->remove(*(*(children.begin())));
     }
+  TRACE_EXIT();
 }
 
 int
@@ -231,7 +239,7 @@ RestBreakWindow::get_exercise_count()
   
   if (Exercise::has_exercises())
     {
-      CoreInterface *core = CoreFactory::get_core();
+      ICore *core = CoreFactory::get_core();
       assert(core != NULL);
       
       ret = core->get_break(BREAK_ID_REST_BREAK)->get_break_exercises();
@@ -251,12 +259,12 @@ RestBreakWindow::install_exercises_panel()
       set_ignore_activity(true);
       clear_pluggable_panel();
       ExercisesPanel *exercises_panel = manage(new ExercisesPanel(NULL));
-      pluggable_panel.pack_start(*exercises_panel, false, false, 0);
+      pluggable_panel->pack_start(*exercises_panel, false, false, 0);
       exercises_panel->set_exercise_count(get_exercise_count());
       exercises_panel->signal_stop().connect
         (MEMBER_SLOT(*this, &RestBreakWindow::install_info_panel));
-      pluggable_panel.show_all();
-      pluggable_panel.queue_resize();
+      pluggable_panel->show_all();
+      pluggable_panel->queue_resize();
       center();
     }
 }
@@ -266,9 +274,9 @@ RestBreakWindow::install_info_panel()
 {
   set_ignore_activity(false);
   clear_pluggable_panel();
-  pluggable_panel.pack_start(*(create_info_panel()), false, false, 0);
-  pluggable_panel.show_all();
-  pluggable_panel.queue_resize();
+  pluggable_panel->pack_start(*(create_info_panel()), false, false, 0);
+  pluggable_panel->show_all();
+  pluggable_panel->queue_resize();
   center();
 }
 
@@ -277,12 +285,12 @@ RestBreakWindow::install_info_panel()
 void
 RestBreakWindow::set_ignore_activity(bool i)
 {
-  CoreInterface *core = CoreFactory::get_core();
+  ICore *core = CoreFactory::get_core();
   assert(core != NULL);
   
   core->set_insist_policy(i ?
-                        CoreInterface::INSIST_POLICY_IGNORE :
+                        ICore::INSIST_POLICY_IGNORE :
                         (block_mode != GUI::BLOCK_MODE_NONE
-                         ? CoreInterface::INSIST_POLICY_HALT
-                         : CoreInterface::INSIST_POLICY_RESET));
+                         ? ICore::INSIST_POLICY_HALT
+                         : ICore::INSIST_POLICY_RESET));
 }
