@@ -1,6 +1,6 @@
 // WorkraveApplet.cc
 //
-// Copyright (C) 2002, 2003, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,17 +14,22 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: WorkraveApplet.c,v 1.5 2006/04/25 21:27:53 rcaelers Exp $";
+static const char rcsid[] = "$Id: WorkraveApplet.c 1129 2007-02-12 22:21:00Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "credits.h"
+
 #include <gnome.h>
 #include <bonobo.h>
 #include <bonobo/bonobo-object.h>
 #include <panel-applet.h>
 
+#include <gtk/gtkaboutdialog.h>
+#include <gdk/gdkx.h>
+
 #include "Workrave-Control.h"
 #include "WorkraveApplet.h"
 #include "nls.h"
@@ -112,7 +117,7 @@ workrave_applet_control_class_init(AppletControlClass *klass)
 
   epv->get_socket_id = workrave_applet_control_get_socket_id;
   epv->get_size = workrave_applet_control_get_size;
-  epv->get_vertical = workrave_applet_control_get_vertical;
+  epv->get_orientation = workrave_applet_control_get_orientation;
   epv->set_menu_status = workrave_applet_control_set_menu_status;
   epv->get_menu_status = workrave_applet_control_get_menu_status;
   epv->set_menu_active = workrave_applet_control_set_menu_active;
@@ -128,7 +133,7 @@ workrave_applet_control_init(AppletControl *applet)
 
   applet->size = 48;
   applet->socket_id = 0;
-  applet->vertical = FALSE;
+  applet->orientation = 0;
 
   applet->last_showlog_state = FALSE;
   applet->last_mode = GNOME_Workrave_WorkraveControl_MODE_INVALID;
@@ -169,12 +174,12 @@ workrave_applet_control_get_size(PortableServer_Servant servant, CORBA_Environme
 }
 
 
-CORBA_boolean
-workrave_applet_control_get_vertical(PortableServer_Servant servant, CORBA_Environment *ev)
+CORBA_long
+workrave_applet_control_get_orientation(PortableServer_Servant servant, CORBA_Environment *ev)
 {
   AppletControl *applet_control = WR_APPLET_CONTROL(bonobo_object_from_servant(servant));
 
-  return applet_control->vertical;
+  return applet_control->orientation;
 }
 
 
@@ -343,42 +348,37 @@ workrave_applet_fire_workrave()
 static void
 verb_about(BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-  /* FIXME: remoe duplicate code... */
-  static const char *authors[] =
-    {
-      "Rob Caelers <robc@krandor.org>",
-      "Raymond Penners <raymond@dotsphinx.com>",
-      NULL
-    };
-
-  const gchar *translators = 
-    "Raymond Penners <raymond@dotsphinx.com>\n"
-    "Johannes Rohr <j.rohr@comlink.apc.org>\n"
-    "Christian Vejlbo <christian@vejlbo.dk>\n"
-    "Mikolaj Machowski <mikmach@wp.pl>\n"
-    "Pablo Rodriguez\n"
-    "Rex Tsai <chihchun@linux.org.tw>\n"
-    "Sergey Kirkinsky <ksa@pfr.altai.ru>\n"
-    "Thomas Basset <thomas.basset@netcourrier.com>\n"
-    "Benjamin Siband <translations@wordinfrench.com>\n"
-    "Claudio Ferreira Filho <filhocf@yahoo.com.br>\n"
-    "Morten Lunde <morten.lunde@broadpark.no>\n"
-    "Juraj Kubelka <Juraj.Kubelka@email.cz>\n"
-    "Artūras Šlajus <x11@h2o.sky.lt>\n"
-    "Haggai Eran <he3@bezeqint.net>\n"
-    "Jordi Mallach <jordi@sindominio.net>\n"
-    "Daniel Nylander <info@danielnylander.se>\n";
-
   GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file(WORKRAVE_DATADIR "/images/workrave.png", NULL);  
-  gtk_widget_show (gnome_about_new
-                   ("Workrave Applet", VERSION,
-                    "Copyright 2001-2006 Rob Caelers & Raymond Penners",
-                    _("This program assists in the prevention and recovery"
-                      " of Repetitive Strain Injury (RSI)."),
-                    (const gchar **) authors,
-                    (const gchar **) NULL,
-                    translators,
-                    pixbuf));
+  GtkAboutDialog *about = GTK_ABOUT_DIALOG(gtk_about_dialog_new());
+  
+  gtk_container_set_border_width(GTK_CONTAINER(about), 5);
+
+
+  gtk_show_about_dialog (NULL,
+			 "name", "Workrave",
+			 "version", VERSION,
+			 "copyright", workrave_copyright,
+			 "website", "http://www.workrave.org",
+			 "website_label", "www.workrave.org",
+			 "comments", _("This program assists in the prevention and recovery"
+                                  " of Repetitive Strain Injury (RSI)."),
+                         "translator-credits", workrave_translators,
+			 "authors", workrave_authors,
+			 "logo", pixbuf,
+			 NULL);
+  g_object_unref(pixbuf);
+
+  
+  
+/*   gtk_widget_show (gnome_about_new */
+/*                    ("Workrave Applet", VERSION, */
+/*                     "Copyright 2001-2006 Rob Caelers & Raymond Penners", */
+/*                     _("This program assists in the prevention and recovery" */
+/*                       " of Repetitive Strain Injury (RSI)."), */
+/*                     (const gchar **) authors, */
+/*                     (const gchar **) NULL, */
+/*                     translators, */
+/*                     pixbuf)); */
 }
 
 
@@ -608,6 +608,8 @@ workrave_applet_verbs [] =
   };
 
 
+
+#if UNRELIABLE__
 static void
 change_pixel_size(PanelApplet *applet, gint size, gpointer data)
 {
@@ -632,15 +634,26 @@ change_pixel_size(PanelApplet *applet, gint size, gpointer data)
       CORBA_exception_free(&ev);
     }
 }
-
+#endif
 
 static void
 change_orient(PanelApplet *applet, PanelAppletOrient o, gpointer data)
 {
-  if(o==PANEL_APPLET_ORIENT_UP || o==PANEL_APPLET_ORIENT_DOWN)
-    applet_control->vertical = FALSE;
-  else
-    applet_control->vertical = TRUE;
+  switch (o)
+    {
+    case PANEL_APPLET_ORIENT_UP:
+      applet_control->orientation = 0;
+      break;
+    case PANEL_APPLET_ORIENT_RIGHT:
+      applet_control->orientation = 1;
+      break;
+    case PANEL_APPLET_ORIENT_DOWN:
+      applet_control->orientation = 2;
+      break;
+    case PANEL_APPLET_ORIENT_LEFT:
+      applet_control->orientation = 3;
+      break;
+    }      
 
   workrave_applet_connect(FALSE);
   
@@ -649,7 +662,7 @@ change_orient(PanelApplet *applet, PanelAppletOrient o, gpointer data)
       CORBA_Environment ev;
       CORBA_exception_init(&ev);
       
-      GNOME_Workrave_WorkraveControl_set_applet_vertical(remote_control, applet_control->vertical, &ev);
+      GNOME_Workrave_WorkraveControl_set_applet_orientation(remote_control, applet_control->orientation, &ev);
       
       if (BONOBO_EX(&ev))
         {
@@ -662,6 +675,63 @@ change_orient(PanelApplet *applet, PanelAppletOrient o, gpointer data)
     }
 }
 
+static void
+change_background (PanelApplet * widget, 
+                   PanelAppletBackgroundType type,
+                   GdkColor * color,
+                   GdkPixmap * pixmap,
+                   void *data)
+{
+  static GdkPixmap *keep = NULL;
+  long xid = 0;
+  GNOME_Workrave_WorkraveControl_Color c;
+  
+  workrave_applet_connect(FALSE);
+  
+  if (remote_control != NULL)
+    {
+      CORBA_Environment ev;
+      CORBA_exception_init(&ev);
+
+      if (type == PANEL_COLOR_BACKGROUND && color != NULL)
+        {
+          c.pixel = color->pixel;
+          c.red = color->red;
+          c.green = color->green;
+          c.blue = color->blue;
+        }
+      
+      if (type == PANEL_PIXMAP_BACKGROUND)
+        {
+          if (keep != NULL)
+            {
+              gdk_pixmap_unref(keep);
+              keep = pixmap;
+            }
+          if (pixmap != NULL)
+            {
+              gdk_pixmap_ref(pixmap);
+            }
+          
+          xid = GDK_PIXMAP_XID(pixmap);
+        }
+
+      
+      GNOME_Workrave_WorkraveControl_set_applet_background(remote_control,
+                                                           type,
+                                                           &c,
+                                                           (CORBA_long) xid,
+                                                           &ev);
+      if (BONOBO_EX(&ev))
+        {
+          char *err = (char *) bonobo_exception_get_text(&ev);
+          g_warning (_("An exception occured '%s'"), err);
+          g_free(err);
+        }
+      
+      CORBA_exception_free(&ev);
+    }
+}
 
 static gboolean
 plug_removed(GtkSocket *socket, void *manager)
@@ -730,7 +800,7 @@ showlog_callback(BonoboUIComponent *ui, const char *path, Bonobo_UIComponent_Eve
 
   new_state = strcmp (state, "0") != 0;
 
-  if (applet_control->last_showlog_state != new_state)
+  if (1) /* FIXME: applet_control->last_showlog_state != new_state) */
     {
       applet_control->last_showlog_state = new_state;
       
@@ -787,8 +857,10 @@ mode_callback(BonoboUIComponent *ui, const char *path, Bonobo_UIComponent_EventT
           mode = GNOME_Workrave_WorkraveControl_MODE_QUIET;
         }
 
-      if (mode != GNOME_Workrave_WorkraveControl_MODE_INVALID &&
-          mode != applet_control->last_mode)
+      if (mode != GNOME_Workrave_WorkraveControl_MODE_INVALID /* FIXME: &&
+                                                                 mode !=
+                                                                 applet_control->last_mode*/
+          ) 
         {
           applet_control->last_mode = mode;
 
@@ -855,16 +927,85 @@ workrave_applet_hide_menus(gboolean hide)
 }
 
 
+/* stolen from clock applet :) */
+static inline void
+force_no_focus_padding (GtkWidget *widget)
+{
+  static gboolean first = TRUE;
+
+  if (first)
+    {
+      gtk_rc_parse_string ("\n"
+                           "   style \"hdate-applet-button-style\"\n"
+                           "   {\n"
+                           "      GtkWidget::focus-line-width=0\n"
+                           "      GtkWidget::focus-padding=0\n"
+                           "   }\n"
+                           "\n"
+                           "    widget \"*.hdate-applet-button\" style \"hdate-applet-button-style\"\n"
+                           "\n");
+      first = FALSE;
+    }
+
+  gtk_widget_set_name (widget, "hdate-applet-button");
+}
+
+void size_allocate(GtkWidget     *widget,
+                   GtkAllocation *allocation,
+                   gpointer       user_data)
+{
+  static int prev_width = -1;
+  static int prev_height = -1;
+
+  if (prev_height == -1 || prev_width == -1 ||
+      allocation->width != prev_width ||
+      allocation->height != prev_height)
+    {
+      prev_height = allocation->height;
+      prev_width = allocation->width;
+
+      if (applet_control->orientation == 1 ||
+          applet_control->orientation == 3)
+        {
+          applet_control->size = allocation->width;
+        }
+      else
+        {
+          applet_control->size = allocation->height;
+        }
+
+      workrave_applet_connect(FALSE);
+  
+      if (remote_control != NULL)
+        {
+          CORBA_Environment ev;
+          CORBA_exception_init(&ev);
+      
+          GNOME_Workrave_WorkraveControl_set_applet_size(remote_control, applet_control->size, &ev);
+      
+          if (BONOBO_EX(&ev))
+            {
+              char *err = (char *) bonobo_exception_get_text(&ev);
+              g_warning (_("An exception occured '%s'"), err);
+              g_free(err);
+            }
+      
+          CORBA_exception_free(&ev);
+        }
+    }
+
+}
+
 static gboolean
 workrave_applet_fill(PanelApplet *applet)
 {
   GdkPixbuf *pixbuf = NULL;
   GtkWidget *hbox = NULL;
   BonoboUIComponent *ui = NULL;
-  GtkWidget *event_box = NULL;
-  
+  PanelAppletOrient orient;
+
   // Create menus.
-  panel_applet_setup_menu_from_file(applet, NULL, "GNOME_WorkraveApplet.xml", NULL,
+  panel_applet_setup_menu_from_file(applet, WORKRAVE_UIDATADIR, "GNOME_WorkraveApplet.xml", NULL,
                                     workrave_applet_verbs, applet);
 
   // Add listeners for menu toggle-items.
@@ -874,44 +1015,74 @@ workrave_applet_fill(PanelApplet *applet)
   bonobo_ui_component_add_listener(ui, "Suspended", mode_callback, NULL);
   bonobo_ui_component_add_listener(ui, "Quiet", mode_callback, NULL);
 
-  // Eventbox
-  event_box = gtk_event_box_new();
-  applet_control->event_box = event_box;
-  gtk_widget_set_events(event_box, gtk_widget_get_events(event_box) | GDK_BUTTON_PRESS_MASK);
-  gtk_widget_show(GTK_WIDGET(event_box));
-  gtk_container_add(GTK_CONTAINER(applet), event_box);
+  panel_applet_set_flags (PANEL_APPLET (applet),
+                          PANEL_APPLET_EXPAND_MINOR);
+  
+  gtk_container_set_border_width(GTK_CONTAINER(applet), 0);
+  panel_applet_set_background_widget(applet, GTK_WIDGET(applet));
+  gtk_widget_set_events(GTK_WIDGET(applet),
+                        gtk_widget_get_events(GTK_WIDGET(applet)) | GDK_BUTTON_PRESS_MASK);
+  
 
-  g_signal_connect(G_OBJECT(event_box), "button_press_event", G_CALLBACK(button_pressed),
+  g_signal_connect(G_OBJECT(applet), "button_press_event", G_CALLBACK(button_pressed),
                    applet_control);
   
   // Socket.
   applet_control->socket = gtk_socket_new();
+  gtk_container_set_border_width(GTK_CONTAINER(applet_control->socket), 0);
   
   // Image
   pixbuf = gdk_pixbuf_new_from_file(WORKRAVE_DATADIR "/images/workrave-icon-medium.png", NULL);  
   applet_control->image = gtk_image_new_from_pixbuf(pixbuf);
-  gtk_widget_show(GTK_WIDGET(applet_control->image));
 
   // Signals.
   g_signal_connect(applet_control->socket, "plug_removed", G_CALLBACK(plug_removed), NULL);
   g_signal_connect(applet_control->socket, "plug_added", G_CALLBACK(plug_added), NULL);
-  g_signal_connect(G_OBJECT(applet), "change_size", G_CALLBACK(change_pixel_size), NULL);
+  /* g_signal_connect(G_OBJECT(applet), "change_size", G_CALLBACK(change_pixel_size), NULL); */
   g_signal_connect(G_OBJECT(applet), "change_orient", G_CALLBACK(change_orient), NULL);
 
   // Container.
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_container_add(GTK_CONTAINER(event_box), hbox);
-  gtk_box_pack_end(GTK_BOX(hbox), applet_control->socket, FALSE, FALSE, 0);
-  gtk_box_pack_end(GTK_BOX(hbox), applet_control->image, FALSE, FALSE, 0);
-
-  gtk_widget_show(GTK_WIDGET(hbox));
-  gtk_widget_show(GTK_WIDGET(applet));
+  hbox = gtk_vbox_new(FALSE, 0);
+  gtk_container_add(GTK_CONTAINER(applet), hbox);
+  gtk_box_pack_end(GTK_BOX(hbox), applet_control->socket, TRUE, TRUE, 0);
+  gtk_box_pack_end(GTK_BOX(hbox), applet_control->image, TRUE, TRUE, 0);
 
+  gtk_container_set_border_width(GTK_CONTAINER(hbox), 0);
+  
   applet_control->socket_id = gtk_socket_get_id(GTK_SOCKET(applet_control->socket));
   applet_control->size = panel_applet_get_size(applet);
 
-  workrave_applet_hide_menus(TRUE);
+  orient = panel_applet_get_orient(applet);
+  
+  switch (orient)
+    {
+    case PANEL_APPLET_ORIENT_UP:
+      applet_control->orientation = 0;
+      break;
+    case PANEL_APPLET_ORIENT_RIGHT:
+      applet_control->orientation = 1;
+      break;
+    case PANEL_APPLET_ORIENT_DOWN:
+      applet_control->orientation = 2;
+      break;
+    case PANEL_APPLET_ORIENT_LEFT:
+      applet_control->orientation = 3;
+      break;
+    }      
 
+  force_no_focus_padding(GTK_WIDGET(applet));
+  force_no_focus_padding(GTK_WIDGET(applet_control->socket));
+  force_no_focus_padding(GTK_WIDGET(applet_control->image));
+  force_no_focus_padding(GTK_WIDGET(hbox));
+
+  gtk_widget_show(GTK_WIDGET(applet_control->image));
+  gtk_widget_show(GTK_WIDGET(applet_control->socket));
+  gtk_widget_show(GTK_WIDGET(hbox));
+  gtk_widget_show(GTK_WIDGET(applet));
+  
+  g_signal_connect(G_OBJECT(applet), "size-allocate", G_CALLBACK(size_allocate), NULL);
+  g_signal_connect(G_OBJECT(applet), "change_background", G_CALLBACK(change_background), NULL);
+  
   return TRUE;
 }
 
