@@ -1,6 +1,6 @@
 // DeskBand.cpp --- CDeskBand implementation
 //
-// Copyright (C) 2004, 2005 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2004, 2005, 2006 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: DeskBand.cpp,v 1.14 2005/02/12 17:31:14 rcaelers Exp $
+// $Id: DeskBand.cpp 1092 2006-10-01 22:03:56Z dotsphinx $
 
 #include <windowsx.h>
 
@@ -560,8 +560,8 @@ CDeskBand::OnCopyData(PCOPYDATASTRUCT copy_data)
             if (bar != NULL)
             {
                 bar->set_text(data->bar_text[b]);
-                bar->set_bar_color((TimeBarInterface::ColorId) data->bar_primary_color[b]);
-                bar->set_secondary_bar_color((TimeBarInterface::ColorId) data->bar_secondary_color[b]);
+                bar->set_bar_color((ITimeBar::ColorId) data->bar_primary_color[b]);
+                bar->set_secondary_bar_color((ITimeBar::ColorId) data->bar_secondary_color[b]);
                 bar->set_progress(data->bar_primary_val[b], data->bar_primary_max[b]);
                 bar->set_secondary_progress(data->bar_secondary_val[b], data->bar_secondary_max[b]);
             }
