@@ -1,6 +1,6 @@
 // TimerBox.h --- Timer box
 //
-// Copyright (C) 2004, 2005 Raymond Penners <raymond@dotsphinx.com>
+// Copyright (C) 2004, 2005, 2006 Raymond Penners <raymond@dotsphinx.com>
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -13,7 +13,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: TimerBox.h,v 1.5 2005/02/12 17:31:14 rcaelers Exp $
+// $Id: TimerBox.h 1092 2006-10-01 22:03:56Z dotsphinx $
 
 #ifndef TIMERBOX_H
 #define TIMERBOX_H
@@ -21,7 +21,7 @@
 #include <windows.h>
 #include <time.h>
 
-#include "CoreInterface.hh"
+#include "ICore.hh"
 #include "Util.h"
 
 class TimeBar;
